#
# spec file for package clamav
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without	clammspack
%bcond_with	valgrind

%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150400
%bcond_without sysuser_vscan
%endif
%if 0%{?suse_version} <= 1500
%define vgcc 13
%if 0%{?sle_version} < 150400
%define vrust 1.78
%define vcmake 3
%endif
%endif
%global confdir %_prefix%_sysconfdir

Name:           clamav
Version:        1.4.2
Release:        3.2
Summary:        Antivirus Toolkit
License:        GPL-2.0-only
Group:          Productivity/Security
URL:            https://www.clamav.net
Source0:        https://www.clamav.net/downloads/production/%{name}-%{version}.tar.gz
Source1:        https://www.clamav.net/downloads/production/%{name}-%{version}.tar.gz.sig
Source4:        clamav-rpmlintrc
Source6:        clamav-tmpfiles.conf
Source7:        service.clamd
Source8:        service.freshclam
Source9:        service.clamav-milter
Source10:       timer.freshclam
# w3m https://www.clamav.net/downloads | sed -n '/-BEGIN /,/-END /p'
Source11:       clamav.keyring
Source12:       service.clamonacc
Source65:       system-user-vscan.conf
Patch1:         clamav-conf.patch
Patch5:         clamav-obsolete-config.patch
Patch12:        clamav-fips.patch
Patch14:        clamav-document-maxsize.patch
Patch15:        clamav-format.patch
ExcludeArch:    %{arml}

BuildRequires:  cargo%{?vrust}
BuildRequires:  cmake%{?vcmake}
BuildRequires:  gcc%{?vgcc}
BuildRequires:  gcc%{?vgcc}-c++
BuildRequires:  libbz2-devel
BuildRequires:  libjson-c-devel
BuildRequires:  libopenssl-devel >= 1.0.2
BuildRequires:  libxml2-devel
BuildRequires:  make
BuildRequires:  rust%{?vrust}
#BuildRequires:  rust+cargo >= 1.61.0
#BuildRequires:  rust+rustc >= 1.61.0
BuildRequires:  sendmail-devel
BuildRequires:  systemd
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libpcre2-8) >= 10.30
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  python(abi) >= 3.6
%if 0%{?suse_version} >= 1500
BuildRequires:  python3-pytest
%endif
#
# Workaround to keep "make check" from using an existing libclamav
# instead of the just built one. This should rather be fixed
# by keeping libtool from adding libdir to rpath and LD_LIBRARY_PATH
# of the test binaries.
#
#!BuildIgnore:    clamav
Obsoletes:      clamav-db < 0.88.3
Provides:       clamav-nodb = %{version}
Obsoletes:      clamav-nodb < %{version}
%if %{without clammspack}
BuildRequires:  pkgconfig(libmspack)
%endif
%if %{with valgrind}
BuildRequires:  valgrind
%endif
%if %{with sysuser_vscan}
Requires(pre):  group(vscan)
Requires(pre):  user(vscan)
%else
BuildRequires:  sysuser-tools
%sysusers_requires
%endif
%{?systemd_ordering}

%description
ClamAV is an antivirus engine designed for detecting trojans,
viruses, malware and other malicious threats. It is the de-facto
standard for mail gateway scanning. It provides a multi-threaded
scanning daemon, command line utilities for on-demand file scanning,
and a tool for automatic signature updates. The core ClamAV library
provides numerous file format detection mechanisms, file unpacking
support, archive support, and multiple signature languages for
detecting threats.

%package docs-html
Summary:        Documentation for ClamAV in HTML format
Group:          Productivity/Security
Requires:       %{name} = %{version}
BuildArch:      noarch

%description docs-html
Optional HTML documentation for ClamAV antivirus engine

%package milter
Summary:        ClamAV Milter compatible mail scanner
Group:          Productivity/Security
Requires:       %{name} = %{version}
Provides:       %{name}:/usr/sbin/clamav-milter

%description milter
ClamAV-milter is a filter for sendmail(1) mail server. It uses a
mail scanning engine built into clamd(8). ClamAV-milter can use
load balancing and fault tolerant techniques to connect to more
than one clamd(8) server and seamlessly hot-swap to even the load
between different machines and to keep scanning for viruses even
when a server goes down.

%package -n libclamav12
Summary:        ClamAV antivirus engine runtime
Group:          System/Libraries

%description -n libclamav12
ClamAV is an antivirus engine designed for detecting trojans,
viruses, malware and other malicious threats.

%package -n libfreshclam3
Summary:        ClamAV updater library
Group:          System/Libraries

%description -n libfreshclam3
ClamAV is an antivirus engine designed for detecting trojans,
viruses, malware and other malicious threats.

%package -n libclammspack0
Summary:        ClamAV antivirus engine runtime
Group:          System/Libraries

%description -n libclammspack0
ClamAV is an antivirus engine designed for detecting trojans,
viruses, malware and other malicious threats.

%package devel
Summary:        Development files for libclamav, an antivirus engine
Group:          Development/Libraries/C and C++
Requires:       libclamav12 = %{version}
Requires:       libfreshclam3 = %{version}

%description devel
ClamAV is an antivirus engine designed for detecting trojans,
viruses, malware and other malicious threats.

This subpackage contains header files for developing applications
that want to make use of libclamav.

%prep
%setup -q
%patch -P 1
%patch -P 5
%patch -P 12
%patch -P 14
%patch -P 15
chmod -x docs/html/images/flamegraph.svg

%build
%if %{without sysuser_vscan}
# Create vscan user
%sysusers_generate_pre %{SOURCE65} vscan
%endif
%cmake \
%if "%{?vgcc}" != ""
    -DCMAKE_C_COMPILER=gcc-%{vgcc} \
    -DCMAKE_CXX_COMPILER=g++-%{vgcc} \
%endif
    -DCMAKE_BUILD_TYPE=DEBUG \
    -DCLAMAV_USER=vscan \
    -DCLAMAV_GROUP=vscan \
    -DCMAKE_INSTALL_DOCDIR:PATH=%{_docdir}/%name \
    -DAPP_CONFIG_DIRECTORY:PATH=%_sysconfdir \
    -DDATABASE_DIRECTORY:PATH=%_localstatedir/lib/clamav \
    -DENABLE_CLAMONACC=ON \
    -DENABLE_MILTER=ON \
    -DSYSTEMD_UNIT_DIR=%{_unitdir} \
    -DPCRE2_LIBRARY=%{_libdir}/libpcre2-8.so \
%if %{without clammspack}
    -DENABLE_EXTERNAL_MSPACK=ON
%endif

%install

%cmake_install
install -d -m755 %{buildroot}%{_localstatedir}/lib/clamav
install -d -m755 %{buildroot}%{_tmpfilesdir}
install -m644 %SOURCE6 %{buildroot}%{_tmpfilesdir}/clamav.conf
%if 0%{?suse_version} <= 1500
mkdir -p %{buildroot}%{_localstatedir}/spool/amavis
%endif
mkdir -p -m 0755 %{buildroot}{%_sysconfdir,/run/clamav}
find %{buildroot} -type f -name "*.la" -delete -print

for f in %{buildroot}%{_sysconfdir}/*.conf.sample;
do
    mv $f ${f%.sample}
done

# Systemd...
rm -f %{buildroot}%{_unitdir}/clamav-*
install -m 0644 %SOURCE7 %{buildroot}%{_unitdir}/clamd.service
install -m 0644 %SOURCE8 %{buildroot}%{_unitdir}/freshclam.service
install -m 0644 %SOURCE9 %{buildroot}%{_unitdir}/clamav-milter.service
install -m 0644 %SOURCE10 %{buildroot}%{_unitdir}/freshclam.timer
install -m 0644 %SOURCE12 %{buildroot}%{_unitdir}/clamonacc.service
for srvname in clamd freshclam clamav-milter clamonacc; do
	(export PATH=%_prefix/sbin:/sbin:$PATH ;ln -sf service %{buildroot}/%{_sbindir}/rc${srvname})
done

%check
# regression tests
%if !0%{?qemu_user_space_build:1} && ( 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150500 )
# Run ctest with a single job to avoid failures
# due to race conditions, e.g. on s390x.
%define _smp_mflags -j1
%ctest
%undefine _smp_mflags
%endif

%if %{with sysuser_vscan}
%pre
%else

%pre -f vscan.pre
%endif
%service_add_pre clamd.service clamonacc.service

%post
%tmpfiles_create %{_tmpfilesdir}/clamav.conf
%service_add_post clamd.service clamonacc.service

%preun
if [ $1 -eq 0 ]; then
	# package will be uninstalled
	rm -f %{_localstatedir}/lib/clamav/*
fi
%service_del_preun clamd.service clamonacc.service

%postun
%service_del_postun clamd.service clamonacc.service

%pre milter
%service_add_pre clamav-milter.service

%post milter
%service_add_post clamav-milter.service

%preun milter
%service_del_preun clamav-milter.service

%postun milter
%service_del_postun clamav-milter.service

%if 0%{?suse_version} > 1500
%ldconfig_scriptlets -n libclamav12
%ldconfig_scriptlets -n libfreshclam3
%if %{with clammspack}
%ldconfig_scriptlets -n libclammspack0
%endif
%else
%post   -n libclamav12 -p /sbin/ldconfig
%postun -n libclamav12 -p /sbin/ldconfig
%post   -n libfreshclam3 -p /sbin/ldconfig
%postun -n libfreshclam3 -p /sbin/ldconfig
%if %{with clammspack}
%post   -n libclammspack0 -p /sbin/ldconfig
%postun -n libclammspack0 -p /sbin/ldconfig
%endif
%endif

%files
%license COPYING.txt COPYING/*
%config(noreplace) %{_sysconfdir}/clamd.conf
%config(noreplace) %{_sysconfdir}/freshclam.conf
%{_bindir}/clamav-config
%{_bindir}/clambc
%{_bindir}/clamconf
%{_bindir}/clamdscan
%{_bindir}/clamdtop
%{_bindir}/clamscan
%{_bindir}/clamsubmit
%{_bindir}/freshclam
%{_bindir}/sigtool
%{_sbindir}/clamd
%{_sbindir}/clamonacc
%{_sbindir}/rcclamd
%{_sbindir}/rcfreshclam
%{_sbindir}/rcclamonacc
%{_mandir}/man1/clambc.1%{?ext_man}
%{_mandir}/man1/clamconf.1%{?ext_man}
%{_mandir}/man1/clamdscan.1%{?ext_man}
%{_mandir}/man1/clamdtop.1%{?ext_man}
%{_mandir}/man1/clamscan.1%{?ext_man}
%{_mandir}/man1/clamsubmit.1%{?ext_man}
%{_mandir}/man1/freshclam.1%{?ext_man}
%{_mandir}/man1/sigtool.1%{?ext_man}
%{_mandir}/man5/clamd.conf.5%{?ext_man}
%{_mandir}/man5/freshclam.conf.5%{?ext_man}
%{_mandir}/man8/clamd.8%{?ext_man}
%{_mandir}/man8/clamonacc.8%{?ext_man}
%{_tmpfilesdir}/*
%{_unitdir}/clamd.service
%{_unitdir}/freshclam.service
%{_unitdir}/freshclam.timer
%{_unitdir}/clamonacc.service
%defattr(-,vscan,vscan)
%dir %{_localstatedir}/lib/clamav
%if 0%{?suse_version} <= 1500
%dir %attr(750,vscan,vscan) %{_localstatedir}/spool/amavis
%endif
%ghost %attr(755,vscan,vscan) /run/clamav

%files docs-html
%doc %_docdir/%name

%files milter
%config(noreplace) %{_sysconfdir}/clamav-milter.conf
%{_unitdir}/clamav-milter.service
%{_sbindir}/clamav-milter
%{_sbindir}/rcclamav-milter
%{_mandir}/man5/clamav-milter.conf.5%{?ext_man}
%{_mandir}/man8/clamav-milter.8%{?ext_man}

%files -n libclamav12
%{_libdir}/libclam*.so.12*

%files -n libfreshclam3
%{_libdir}/libfreshclam.so.3*

%if %{with clammspack}
%files -n libclammspack0
%{_libdir}/libclammspack.so.0*
%endif

%files devel
%{_includedir}/*
%{_libdir}/pkgconfig/*
%{_libdir}/libclam*.so
%{_libdir}/libfreshclam*.so
%{_libdir}/libclamav_rust.a

%changelog
* Mon Feb 10 2025 Reinhard Max <max@suse.com>
- bsc#1236949: Fix location of license files.
* Thu Jan 23 2025 Reinhard Max <max@suse.com>
- Drop the version dependency on libcurl. Building against versions
  older than 7.45 does not fail anymore, but disables support for
  fdpassing in clamonacc. This only affects SLE-12 up to SP3.
* Wed Jan 22 2025 Reinhard Max <max@suse.com>
- New version 1.4.2:
  * CVE-2025-20128, bsc#1236307: Fixed a possible buffer overflow
    read bug in the OLE2 file parser that could cause a
    denial-of-service (DoS) condition.
* Fri Jan 10 2025 Reinhard Max <max@suse.com>
- bsc#1232242: Start clamonacc with --fdpass to avoid errors due to
  clamd not being able to access user files.
* Wed Dec 18 2024 Andreas Stieger <andreas.stieger@gmx.de>
- fix factory submission (clam.tcl, clamscan.log)
* Tue Sep 10 2024 Reinhard Max <max@suse.com>
- New version 1.4.1:
  * [CVE-2024-20506, bsc#1230162]: Changed the logging module to
    disable following symlinks on Linux and Unix systems so as to
    prevent an attacker with existing access to the 'clamd' or
    'freshclam' services from using a symlink to corrupt system
    files.
  * [CVE-2024-20505, bsc#1230161]: Fixed a possible out-of-bounds
    read bug in the PDF file parser that could cause a
    denial-of-service (DoS) condition.
  * https://blog.clamav.net/2024/09/clamav-141-132-107-and-010312-security.html
- New version 1.4.0:
  * Added support for extracting ALZ archives.
  * Added support for extracting LHA/LZH archives.
  * Added the ability to disable image fuzzy hashing, if needed.
    For context, image fuzzy hashing is a detection mechanism
    useful for identifying malware by matching images included with
    the malware or phishing email/document.
  * https://blog.clamav.net/2024/08/clamav-140-feature-release-and-clamav.html
* Wed Sep  4 2024 Arjen de Korte <suse+build@de-korte.org>
- New version 1.3.2:
  * CVE-2024-20506: Changed the logging module to disable following
    symlinks on Linux and Unix systems so as to prevent an attacker
    with existing access to the 'clamd' or 'freshclam' services from
    using a symlink to corrupt system files.
  * CVE-2024-20505: Fixed a possible out-of-bounds read bug in the PDF
    file parser that could cause a denial-of-service condition.
  * Removed unused Python modules from freshclam tests including
    deprecated 'cgi' module that is expected to cause test failures in
    Python 3.13.
  * Fix unit test caused by expiring signing certificate.
  * Fixed a build issue on Windows with newer versions of Rust. Also
    upgraded GitHub Actions imports to fix CI failures.
  * Fixed an unaligned pointer dereference issue on select architectures.
  * Fixes to Jenkins CI pipeline.
- Remove upstreamed 1305.patch
* Mon Jul 29 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Add upstream 1305.patch to fix tests (boo#1102840, https://github.com/Cisco-Talos/clamav/issues/1300)
* Mon Apr 22 2024 Reinhard Max <max@suse.com>
- New Version: 1.3.1:
  * CVE-2024-20380: Fixed a possible crash in the HTML file parser
    that could cause a denial-of-service (DoS) condition.
  * Updated select Rust dependencies to the latest versions.
  * Fixed a bug causing some text to be truncated when converting
    from UTF-16.
  * Fixed assorted complaints identified by Coverity static
    analysis.
  * Fixed a bug causing CVDs downloaded by the DatabaseCustomURL
    Freshclam config option to be pruned and then re-downloaded
    with every update.
  * Added the new 'valhalla' database name to the list of optional
    databases in preparation for future work.
* Fri Mar 15 2024 Reinhard Max <max@suse.com>
- New version: 1.3.0:
  * Added support for extracting and scanning attachments found in
    Microsoft OneNote section files. OneNote parsing will be
    enabled by default, but may be optionally disabled.
  * Added file type recognition for compiled Python (`.pyc`) files.
  * Improved support for decrypting PDFs with empty passwords.
  * Fixed a warning when scanning some HTML files.
  * ClamOnAcc: Fixed an infinite loop when a watched directory
    does not exist.
  * ClamOnAcc: Fixed an infinite loop when a file has been deleted
    before a scan.
- New version: 1.2.0:
  * Added support for extracting Universal Disk Format (UDF)
    partitions.
  * Added an option to customize the size of ClamAV's clean file
    cache.
  * Raised the MaxScanSize limit so the total amount of data
    scanned when scanning a file or archive may exceed 4 gigabytes.
  * Added ability for Freshclam to use a client certificate PEM
    file and a private key PEM file for authentication to a private
    mirror.
  * Fix an issue extracting files from ISO9660 partitions where the
    files are listed in the plain ISO tree and there also exists an
    empty Joliet tree.
  * PID and socket are now located under /run/clamav/clamd.pid and
    /run/clamav/clamd.sock .
  * bsc#1211594: Fixed an issue where ClamAV does not abort the
    signature load process after partially loading an invalid
    signature.
- New version 1.1.0:
  * https://blog.clamav.net/2023/05/clamav-110-released.html
  * Added the ability to extract images embedded in HTML CSS
    <style> blocks.
  * Updated to Sigtool so that the --vba option will extract VBA
    code from Microsoft Office documents the same way that
    libclamav extracts VBA.
  * Added a new option --fail-if-cvd-older-than=days to clamscan
    and clamd, and FailIfCvdOlderThan to clamd.conf
  * Added a new function cl_cvdgetage() to the libclamav API.
  * Added a new function cl_engine_set_clcb_vba() to the
    libclamav API.
  * obsoletes clamav-ec32.patch.
- boo#1180296: Integrate clamonacc as a service.
- New version 1.0.1 LTS (including changes in 0.104 and 0.105):
  * As of ClamAV 0.104, CMake is required to build ClamAV.
  * As of ClamAV 0.105, Rust is now required to compile ClamAV.
  * Increased the default limits for file and scan size:
  * MaxScanSize: 100M to 400M
  * MaxFileSize: 25M to 100M
  * StreamMaxLength: 25M to 100M
  * PCREMaxFileSize: 25M to 100M
  * MaxEmbeddedPE: 10M to 40M
  * MaxHTMLNormalize: 10M to 40M
  * MaxScriptNormalize: 5M to 20M
  * MaxHTMLNoTags: 2M to 8M
  * Added image fuzzy hash subsignatures for logical signatures.
  * Support for decrypting read-only OLE2-based XLS files that are
    encrypted with the default password.
  * Overhauled the implementation of the all-match feature.
  * Added a new callback to the public API for inspecting file
    content during a scan at each layer of archive extraction.
  * Added a new function to the public API for unpacking CVD
    signature archives.
  * The option to build with an external TomsFastMath library has
    been removed. ClamAV requires non-default build options for
    TomsFastMath to support bigger floating point numbers.
  * For a full list of changes see the release announcements:
  * https://blog.clamav.net/2022/11/clamav-100-lts-released.html
  * https://blog.clamav.net/2022/05/clamav-01050-01043-01036-released.html
  * https://blog.clamav.net/2021/09/clamav-01040-released.html
- Build clamd with systemd support.
- Fix format strings on 32bit platforms (clamav-format.patch).
- Add missing endianness conversions (clamav-ec32.patch).
- Don't build on armv7l for now due to some test failures.
- Drop clamav-disable-yara.patch as yara cannot be disabled anymore
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Oct 25 2023 Arjen de Korte <suse+build@de-korte.org>
- Update to 0.103.11
  * Upgrade the bundled UnRAR library (libclamunrar) to version 6.2.12.
  * Windows: libjson-c 0.17 compatibility fix. with ssize_t type definition.
  * Windows: Update build system to use OpenSSL 3 and PThreads-Win32 v3.
- Update to 0.103.10
  * Upgrade the bundled UnRAR library (libclamunrar) to version 6.2.10.
    (bsc#1216625, CVE-2023-40477)
* Fri Aug 18 2023 Reinhard Max <max@suse.com>
- Renew clamav.keyring .
* Wed Aug 16 2023 Arjen de Korte <suse+build@de-korte.org>
- Update to 0.103.9
  * CVE-2023-20197: Fixed a possible denial of service vulnerability in
    the HFS+ file parser. This issue affects versions 1.1.0, 1.0.1 through
    1.0.0, 0.105.2 through 0.105.0, 0.104.4 through 0.104.0, and 0.103.8
    through 0.103.0. (boo#1214342)
  * Fixed compiler warnings that may turn into errors in Clang 16.
* Wed Feb 15 2023 Arjen de Korte <suse+build@de-korte.org>
- Update to 0.103.8
  * CVE-2023-20032: Fixed a possible remote code execution vulnerability
    in the HFS+ file parser. Issue affects versions 1.0.0 and earlier,
    0.105.1 and earlier, and 0.103.7 and earlier. (bsc#1208363)
  * CVE-2023-20052: Fixed a possible remote information leak
    vulnerability in the DMG file parser. Issue affects versions 1.0.0
    and earlier, 0.105.1 and earlier, and 0.103.7 and earlier.
    (bsc#1208365)
  * Update vendored libmspack library to version 0.11alpha.
    (bsc#1103032: CVE-2018-14679)
- Package huge .html documentation in a separate subpackage.
* Fri Aug  5 2022 ecsos <ecsos@opensuse.org>
- Update to 0.103.7 (bsc#1202986)
  - Zip parser: tolerate 2-byte overlap in file entries
  - Fix bug with logical signature Intermediates feature
  - Update to UnRAR v6.1.7
  - Patch UnRAR: allow skipping files in solid archives
  - Patch UnRAR: limit dict winsize to 1GB
* Thu May  5 2022 Arjen de Korte <suse+build@de-korte.org>
- Update to 0.103.6
  * CVE-2022-20770: Fixed a possible infinite loop vulnerability in the CHM
    file parser. Issue affects versions 0.104.0 through 0.104.2 and LTS
    version 0.103.5 and prior versions. (boo#1199242)
  * CVE-2022-20796: Fixed a possible NULL-pointer dereference crash in the
    scan verdict cache check. Issue affects versions 0.103.4, 0.103.5,
    0.104.1, and 0.104.2. (boo#1199246)
  * CVE-2022-20771: Fixed a possible infinite loop vulnerability in the
    TIFF file parser. Issue affects versions 0.104.0 through 0.104.2 and
    LTS version 0.103.5 and prior versions. The issue only occurs if the
    "--alert-broken-media" ClamScan option is enabled. For ClamD, the
    affected option is "AlertBrokenMedia yes", and for libclamav it is the
    "CL_SCAN_HEURISTIC_BROKEN_MEDIA" scan option. (boo#1199244)
  * CVE-2022-20785: Fixed a possible memory leak in the HTML file parser /
    Javascript normalizer. Issue affects versions 0.104.0 through 0.104.2
    and LTS version 0.103.5 and prior versions. (boo#1199245)
  * CVE-2022-20792: Fixed a possible multi-byte heap buffer overflow write
    vulnerability in the signature database load module. The fix was to
    update the vendored regex library to the latest version. Issue affects
    versions 0.104.0 through 0.104.2 and LTS version 0.103.5 and prior
    versions. (boo#1199274)
  * ClamOnAcc: Fixed a number of assorted stability issues and added
    niceties for debugging ClamOnAcc.
  * Fixed an issue causing byte-compare subsignatures to cause an alert
    when they match even if other conditions of the given logical
    signatures were not met.
  * Fix memleak when using multiple byte-compare subsignatures. This fix
    was backported from 0.104.0.
  * Assorted bug fixes and improvements.
- Remove upstreamed clamav-ck_assert_msg.patch
* Tue Apr 12 2022 Marcus Meissner <meissner@suse.com>
- https source urls
* Wed Jan 12 2022 Arjen de Korte <suse+build@de-korte.org>
- Update to 0.103.5
  * CVE-2022-20698: Fix for invalid pointer read that may cause a crash.
    This issue affects 0.104.1, 0.103.4 and prior when ClamAV is compiled
    with libjson-c and the CL_SCAN_GENERAL_COLLECT_METADATA scan option
    (the clamscan --gen-json option) is enabled. (bsc#1194731)
  * Fixed ability to disable the file size limit with libclamav C API,
    like this:
    cl_engine_set_num(engine, CL_ENGINE_MAX_FILESIZE, 0);
    This issue didn't affect ClamD or ClamScan which also can disable the
    limit by setting it to zero using MaxFileSize 0 in clamd.conf for ClamD,
    or clamscan --max-filesize=0 for ClamScan.
    Note: Internally, the max file size is still set to 2 GiB. Disabling the
    limit for a scan will fall back on the internal 2 GiB limitation.
  * Increased the maximum line length for ClamAV config files from 512 bytes
    to 1,024 bytes to allow for longer config option strings.
  * SigTool: Fix insufficient buffer size for --list-sigs that caused a
    failure when listing a database containing one or more very long
    signatures. This fix was backported from 0.104.
* Wed Nov  3 2021 Arjen de Korte <suse+build@de-korte.org>
- bsc#1192346: Update to 0.103.4
  * FreshClam:
  - Add a 24-hour cool-down for FreshClam clients that have received
    an HTTP 403 (Forbidden) response from the CDN. This is to reduce
    the volume of 403-response data served to blocked FreshClam
    clients that are configured with a tight update-loop.
  - Fixed a bug where FreshClam treats an empty CDIFF as an
    incremental update failure instead of as an intentional request
    to download the whole CVD.
  * ClamDScan: Fix a scan error when broken symlinks are encountered on
    macOS with "FollowDirectorySymlinks" and "FollowFileSymlinks"
    options disabled.
  * Overhauled the scan recursion / nested archive extraction logic and
    added new limits on embedded file-type recognition performed during
    the "raw" scan of each file. This limits embedded file-type
    misidentification and prevents detecting embedded file content that
    is found/extracted and scanned at other layers in the scanning
    process.
  * Fix an issue with the FMap module that failed to read from some
    nested files.
  * Fixed an issue where failing to load some rules from a Yara file
    containing multiple rules may cause a crash.
  * Fixed assorted compiler warnings.
  * Fixed assorted Coverity static code analysis issues.
  * Scan limits:
  - Added virus-name suffixes to the alerts that trigger when a scan
    limit has been exceeded. Rather than simply
    Heuristics.Limits.Exceeded, you may now see limit-specific
    virus-names, to include:
    + Heuristics.Limits.Exceeded.MaxFileSize
    + Heuristics.Limits.Exceeded.MaxScanSize
    + Heuristics.Limits.Exceeded.MaxFiles
    + Heuristics.Limits.Exceeded.MaxRecursion
    + Heuristics.Limits.Exceeded.MaxScanTime
  - Renamed the Heuristics.Email.ExceedsMax.* alerts to align with
    the other limit alerts names. These alerts include:
    + Heuristics.Limits.Exceeded.EmailLineFoldcnt
    + Heuristics.Limits.Exceeded.EmailHeaderBytes
    + Heuristics.Limits.Exceeded.EmailHeaders
    + Heuristics.Limits.Exceeded.EmailMIMEPartsPerMessage
    + Heuristics.Limits.Exceeded.EmailMIMEArguments
  - Fixed an issue where the Email-related scan limits would alert
    even when the "AlertExceedsMax" (--alert-exceeds-max) scan option
    is not enabled.
  - Fixes an issue in the Zip parser where exceeding the "MaxFiles"
    limit or the "MaxFileSize" limit would abort the scan but would
    fail to alert. The Zip scan limit issues were independently
    identified and reported by Aaron Leliaert and Max Allan.
  * Fixed a leak in the Email parser when using the --gen-json scan
    option.
  * Fixed an issue where a failure to record metadata in the Email
    parser when using the --gen-json scan option could cause the Email
    parser to abort the scan early and fail to extract and scan
    additional content.
  * Fixed a file name memory leak in the Zip parser.
  * Fixed an issue where certain signature patterns may cause a crash or
    cause unintended matches on some systems when converting characters
    to uppercase if a UTF-8 unicode single-byte grapheme becomes a
    multi-byte grapheme. Patch courtesy of Andrea De Pasquale.
* Wed Jun 30 2021 Marcus Meissner <meissner@suse.com>
- clamav-document-maxsize.patch: in the "clamscan" and "clamdscan" manpages,
  document that files over a certain size by default will silently not be
  scanned and how this can be adjusted (bsc#1187509)
* Mon Jun 21 2021 Arjen de Korte <suse+build@de-korte.org>
- bsc#1188284: Update to 0.103.3
  * Fixed a scan performance issue when ENGINE_OPTIONS_FORCE_TO_DISK is
    enabled. This issue did not impacted most users but for those
    affected it caused every scanned file to be copied to the temp
    directory before the scan.
  * Fix ClamDScan crashes when using the --fdpass --multiscan
    command-line options in combination with the ClamD ExcludePath
    config file options.
  * Fixed an issue where the mirrors.dat file is owned by root when
    starting as root (or with sudo) and using daemon-mode. File
    ownership will be set to the DatabaseOwner just before FreshClam
    switches to run as that user.
  * Renamed the mirrors.dat file to freshclam.dat.
  * Disabled the HTTPUserAgent config option if the DatabaseMirror uses
    clamav.net. This will prevent users from being inadvertently blocked
    and will ensure that we can keep better metrics on which ClamAV
    versions are being used.
  * Moved the detection for Heuristics.PNG.CVE-2010-1205 behind the
    ClamScan --alert-broken-media option (ClamD AlertBrokenMedia yes)
    option. This type of PNG issue appears to be common enough to be an
    annoyance, and the CVE is old enough that no one should be
    vulnerable at this point.
  * Fix ClamSubmit failures after changes to Cloudflare "__cfduid"
    cookies. See: https://blog.cloudflare.com/deprecating-cfduid-cookie/
* Fri Apr  9 2021 Reinhard Max <max@suse.com>
- Use a split-provides for clamav-milter instead of recommending it.
* Wed Apr  7 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to 0.103.2
  * CVE-2021-1252, bsc#1184532: Fix for Excel XLM parser infinite
    loop. Affects 0.103.0 and 0.103.1 only.
  * CVE-2021-1404, bsc#1184533: Fix for PDF parser buffer over-read;
    possible crash. Affects 0.103.0 and 0.103.1 only.
  * CVE-2021-1405, bsc#1184534: Fix for mail parser
    NULL-dereference crash. Affects 0.103.1 and prior.
  * Fix possible memory leak in PNG parser.
  * Fix ClamOnAcc scan on file-creation race condition so files are
    scanned after their contents are written.
  * FreshClam: Deprecate the SafeBrowsing config option. The
    SafeBrowsing option will no longer do anything.
  * For more details, see our blog post from last year about the
    future of the ClamAV Safe Browsing database.
  * FreshClam: Improved HTTP 304, 403, & 429 handling.
  * FreshClam: Added back the mirrors.dat file to the database directory.
  * FreshClam will now exit with a failure in daemon mode if an HTTP 403
    (Forbidden) was received, because retrying later won't help any. The
    FreshClam user will have to take actions to get unblocked.
  * Fix the FreshClam mirror-sync issue where a downloaded database is
    "older than the version advertised."
  * bsc#1181256: Fix errors when scanning files > 4G
- Update package signing key (from https://www.clamav.net/downloads)
  %% clamav.keyring
* Thu Feb 25 2021 Arjen de Korte <suse+build@de-korte.org>
- Package clamav-milter in a subpackage
- Remove virus signatures upon uninstall
- Check for database existence before starting clamd
- Restart clamd when it exits
* Tue Feb  9 2021 Arjen de Korte <suse+build@de-korte.org>
- Don't daemonize freshclam, but use a systemd timer instead to
  trigger updates
  + timer.freshclam
  %% service.freshclam
  %% clamav-conf.patch
- Remove obsolete patch (replaced by SOURCE_DATE_EPOCH)
  - clamav-disable-timestamps.patch
- Fix unit test
  + clamav-ck_assert_msg.patch
- Cleanup spec
  * use pkgconfig() to resolve BuildRequires where upstream uses it
  * rework creating vscan user (new system-user in Tumbleweed)
  * remove obsolete configure option --disable-zlib-vcheck
* Sat Feb  6 2021 Arjen de Korte <suse+build@de-korte.org>
- Update to 0.103.1
  * Added a new scan option to alert on broken media (graphics) file
    formats. This feature mitigates the risk of malformed media files
    intended to exploit vulnerabilities in other software. At present
    media validation exists for JPEG, TIFF, PNG, and GIF files. To
    enable this feature, set AlertBrokenMedia yes in clamd.conf, or
    use the --alert-broken-media option when using clamscan. These
    options are disabled by default in this patch release, but may be
    enabled in a subsequent release. Application developers may enable
    this scan option by enabling CL_SCAN_HEURISTIC_BROKEN_MEDIA for
    the heuristic scan option bit field.
  * Added CL_TYPE_TIFF, CL_TYPE_JPEG types to match GIF, PNG typing
    behavior. BMP and JPEG 2000 files will continue to detect as
    CL_TYPE_GRAPHICS because ClamAV does not yet have BMP or JPEG
    2000 format checking capabilities.
  * Fixed PNG parser logic bugs that caused an excess of parsing
    errors and fixed a stack exhaustion issue affecting some systems
    when scanning PNG files. PNG file type detection was disabled via
    signature database update for ClamAV version 0.103.0 to mitigate
    the effects from these bugs.
  * Fixed an issue where PNG and GIF files no longer work with
    Target:5 graphics signatures if detected as CL_TYPE_PNG/GIF rather
    than as CL_TYPE_GRAPHICS. Target types now support up to 10
    possible file types to make way for additional graphics types in
    future releases.
  * Fixed clamonacc's --fdpass option.
  - Interprocess file descriptor passing for clamonacc was broken
    since version 0.102.0 due to a bug introduced by the switch to
    curl for communicating with clamd. On Linux, passing file
    descriptors from one process to another is handled by the
    kernel, so we reverted clamonacc to use standard system calls
    for socket communication when fd passing is enabled.
  * Fixed a clamonacc stack corruption issue on some systems when
    using an older version of libcurl.
  * Allow clamscan and clamdscan scans to proceed even if the
    realpath lookup failed. This alleviates an issue on Windows
    scanning files hosted on file- systems that do not support the
    GetMappedFileNameW() API such as on ImDisk RAM-disks.
  * Fixed freshclam --on-update-execute=EXIT_1 temporary directory
    cleanup issue.
  * clamd's log output and VirusEvent now provide the scan target's
    file path instead of a file descriptor. The clamd socket API for
    submitting a scan by FD-passing doesn't include a file path, this
    feature works by looking up the file path by file descriptor.
    This feature works on Mac and Linux but is not yet implemented
    for other UNIX operating systems. FD-passing is not available for
    Windows.
  * Fixed an issue where freshclam database validation didn't work
    correctly when run in daemon mode on Linux/Unix.
* Thu Nov 12 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Do not hard-depend on systemd: use systemd_ordering instead of
  systemd_requires.
* Tue Nov 10 2020 Reinhard Max <max@suse.com>
- Sync Factory to SLE-15 to implement jsc#ECO-3010 and bsc#1118459.
- bsc#1119353, clamav-fips.patch: Fix freshclam crash in FIPS mode.
- Keep OBS from installing an existing clamav instance to scan the
  sources, because this makes "make check" use the old library
  instead of the just built one. This is only a workaround until
  we found a way to keep libtool from adding libdir to rpath and
  LD_LIBRARY_PATH of the binaries in the testsuite.
* Mon Sep 14 2020 Arjen de Korte <suse+build@de-korte.org>
- Update to 0.103.0
  * clamd can now reload the signature database without blocking
    scanning. This multi-threaded database reload improvement was made
    possible thanks to a community effort.
  - Non-blocking database reloads are now the default behavior. Some
    systems that are more constrained on RAM may need to disable
    non-blocking reloads as it will temporarily consume two times as
    much memory. We added a new clamd config option
    ConcurrentDatabaseReload, which may be set to no.
  * Dropped clamav-str-h.patch (no longer needed)
  * Fix clamav-milter.service (requires clamd.service to run)
* Thu Jul 16 2020 Arjen de Korte <suse+build@de-korte.org>
- Update to 0.102.4
  * CVE-2020-3350: Fix a vulnerability wherein a malicious user could
    replace a scan target's directory with a symlink to another path
    to trick clamscan, clamdscan, or clamonacc into removing or moving
    a different file (eg. a critical system file). The issue would
    affect users that use the --move or --remove options for clamscan,
    clamdscan, and clamonacc. (bsc#1174255)
  * CVE-2020-3327: Fix a vulnerability in the ARJ archive parsing
    module in ClamAV 0.102.3 that could cause a Denial-of-Service
    (DoS) condition. Improper bounds checking results in an
    out-of-bounds read which could cause a crash. The previous fix for
    this CVE in 0.102.3 was incomplete. This fix correctly resolves
    the issue.
  * CVE-2020-3481: Fix a vulnerability in the EGG archive module in
    ClamAV 0.102.0 - 0.102.3 could cause a Denial-of-Service (DoS)
    condition. Improper error handling may result in a crash due to a
    NULL pointer dereference. This vulnerability is mitigated for
    those using the official ClamAV signature databases because the
    file type signatures in daily.cvd will not enable the EGG archive
    parser in versions affected by the vulnerability. (bsc#1174250)
* Tue May 12 2020 Arjen de Korte <suse+build@de-korte.org>
- Update to 0.102.3
  * CVE-2020-3327: Fix a vulnerability in the ARJ archive parsing
    module in ClamAV 0.102.2 that could cause a Denial-of-Service (DoS)
    condition. Improper bounds checking of an unsigned variable results
    in an out-of-bounds read which causes a crash.
  * CVE-2020-3341: Fix a vulnerability in the PDF parsing module in
    ClamAV 0.101 - 0.102.2 that could cause a Denial-of-Service (DoS)
    condition. Improper size checking of a buffer used to initialize AES
    decryption routines results in an out-of-bounds read which may cause
    a crash. (bsc#1171981)
  * Fix "Attempt to allocate 0 bytes" error when parsing some PDF
    documents.
  * Fix a couple of minor memory leaks.
  * Updated libclamunrar to UnRAR 5.9.2.
* Wed Apr  1 2020 Martin Pluskal <mpluskal@suse.com>
- Drop python build dependency as it is not needed
* Wed Feb  5 2020 Arjen de Korte <suse+build@de-korte.org>
- update to 0.102.2
  * CVE-2020-3123: A denial-of-service (DoS) condition may occur when
    using the optional credit card data-loss-prevention (DLP) feature.
    Improper bounds checking of an unsigned variable resulted in an
    out-of-bounds read, which causes a crash.
  * Significantly improved the scan speed of PDF files on Windows.
  * Re-applied a fix to alleviate file access issues when scanning RAR
    files in downstream projects that use libclamav where the scanning
    engine is operating in a low-privilege process. This bug was originally
    fixed in 0.101.2 and the fix was mistakenly omitted from 0.102.0.
  * Fixed an issue where freshclam failed to update if the database version
    downloaded is one version older than advertised. This situation may
    occur after a new database version is published. The issue affected
    users downloading the whole CVD database file.
  * Changed the default freshclam ReceiveTimeout setting to 0 (infinite).
    The ReceiveTimeout had caused needless database update failures for
    users with slower internet connections.
  * Correctly display the number of kilobytes (KiB) in progress bar and
    reduced the size of the progress bar to accommodate 80-character width
    terminals.
  * Fixed an issue where running freshclam manually causes a daemonized
    freshclam process to fail when it updates because the manual instance
    deletes the temporary download directory. The freshclam temporary files
    will now download to a unique directory created at the time of an update
    instead of using a hardcoded directory created/destroyed at the program
    start/exit.
  * Fix for freshclam's OnOutdatedExecute config option.
  * Fixes a memory leak in the error condition handling for the email
    parser.
  * Improved bound checking and error handling in ARJ archive parser.
  * Improved error handling in PDF parser.
  * Fix for memory leak in byte-compare signature handler.
* Tue Dec 24 2019 Arjen de Korte <suse+build@de-korte.org>
- The freshclam.service should not be started before the network is
  online (it checks for updates immediately upon service start)
* Thu Dec 19 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libsystemd) instead of systemd-devel:
  Allow OBS to shortcut through the -mini flavors.
* Wed Nov 20 2019 Arjen de Korte <suse+build@de-korte.org>
- update to 0.102.1
  * CVE-2019-15961, bsc#1157763: A Denial-of-Service (DoS)
    vulnerability may occur when scanning a specially crafted email
    file as a result of excessively long scan times. The issue is
    resolved by implementing several maximums in parsing MIME
    messages and by optimizing use of memory allocation.
  * Build system fixes to build clamav-milter, to correctly link
    with libxml2 when detected, and to correctly detect fanotify
    for on-access scanning feature support.
  * Signature load time is significantly reduced by changing to a
    more efficient algorithm for loading signature patterns and
    allocating the AC trie. Patch courtesy of Alberto Wu.
  * Introduced a new configure option to statically link libjson-c
    with libclamav. Static linking with libjson is highly
    recommended to prevent crashes in applications that use
    libclamav alongside another JSON parsing library.
  * Null-dereference fix in email parser when using the
  - -gen-json metadata option.
  * Fixes for Authenticode parsing and certificate signature
    (.crb database) bugs.
- dropped clamav-fix_building_milter.patch (upstreamed)
* Fri Nov  1 2019 Arjen de Korte <suse+build@de-korte.org>
- update to 0.102.0
  * The On-Access Scanning feature has been migrated out of clamd
    and into a brand new utility named clamonacc. This utility is
    similar to clamdscan and clamav-milter in that it acts as a
    client to clamd. This separation from clamd means that clamd no
    longer needs to run with root privileges while scanning potentially
    malicious files. Instead, clamd may drop privileges to run under an
    account that does not have super-user. In addition to improving the
    security posture of running clamd with On-Access enabled, this
    update fixed a few outstanding defects:
  - On-Access scanning for created and moved files (Extra-Scanning)
    is fixed.
  - VirusEvent for On-Access scans is fixed.
  - With clamonacc, it is now possible to copy, move, or remove a
    file if the scan triggered an alert, just like with clamdscan.
  * The freshclam database update utility has undergone a significant
    update. This includes:
  - Added support for HTTPS.
  - Support for database mirrors hosted on ports other than 80.
  - Removal of the mirror management feature (mirrors.dat).
  - An all new libfreshclam library API.
- created new subpackage libfreshclam2
- dropped clamav-max_patch.patch (upstreamed)
- added clamav-fix_building_milter.patch to fix build of milter
* Fri Oct 25 2019 Reinhard Max <max@suse.com>
- bsc#1151839: Increase the startup timeout of clamd to 5 minutes
  to cater for the grown virus database as a workaround until
  clamd has learned to talk to systemd to extend the timeout as
  long as needed.
* Wed Sep  4 2019 Andreas Stieger <andreas.stieger@gmx.de>
- update to 0.101.4:
  * CVE-2019-12900: An out of bounds write in the NSIS bzip2
    (boo#1149458)
  * CVE-2019-12625: Introduce a configurable time limit to mitigate
    zip bomb vulnerability completely. Default is 2 minutes,
    configurable useing the clamscan --max-scantime and for clamd
    using the MaxScanTime config option (boo#1144504)
* Tue Aug  6 2019 Reinhard Max <max@suse.com>
- Update to version 0.101.3:
  * bsc#1144504: ZIP bomb causes extreme CPU spikes
* Wed Mar 27 2019 Andrey Karepin <egdfree@opensuse.org>
- Update to version 0.101.2 (bsc#1130721)
  * CVE-2019-1787:
    An out-of-bounds heap read condition may occur when scanning PDF
    documents. The defect is a failure to correctly keep track of the number
    of bytes remaining in a buffer when indexing file data.
  * CVE-2019-1789:
    An out-of-bounds heap read condition may occur when scanning PE files
    (i.e. Windows EXE and DLL files) that have been packed using Aspack as a
    result of inadequate bound-checking.
  * CVE-2019-1788:
    An out-of-bounds heap write condition may occur when scanning OLE2 files
    such as Microsoft Office 97-2003 documents. The invalid write happens when
    an invalid pointer is mistakenly used to initialize a 32bit integer to
    zero. This is likely to crash the application.
  * CVE-2019-1786:
    An out-of-bounds heap read condition may occur when scanning malformed
    PDF documents as a result of improper bounds-checking.
  * CVE-2019-1785:
    A path-traversal write condition may occur as a result of improper
    input validation when scanning RAR archives.
  * CVE-2019-1798:
    A use-after-free condition may occur as a result of improper error
    handling when scanning nested RAR archives.
- added clamav-max_patch.patch to fix build
- dropped clamav-freshclam-exit.patch
* Mon Jan 21 2019 Reinhard Max <max@suse.com>
- Update to version 0.101.1:
  * Add missing headers to fix build of packages against libclamav.
- Add missing include for str.h to libclamav/others_common.c
  (clamav-str-h.patch)
* Thu Oct  4 2018 Reinhard Max <max@suse.com>
- Update to version 0.100.2:
  * bsc#1110723, CVE-2018-15378: Vulnerability in ClamAV's MEW
    unpacking feature that could allow an unauthenticated, remote
    attacker to cause a denial of service (DoS) condition on an
    affected device.
  * bsc#1103040, CVE-2018-14680, CVE-2018-14681, CVE-2018-14682:
    more fixes for embedded libmspack.
  * Make freshclam more robust against lagging signature mirrors.
  * On-Access "Extra Scanning", an opt-in minor feature of
    OnAccess scanning on Linux systems, has been disabled due to a
    known issue with resource cleanup OnAccessExtraScanning will
    be re-enabled in a future release when the issue is
    resolved. In the mean-time, users who enabled the feature in
    clamd.conf will see a warning informing them that the feature
    is not active. For details, see:
    https://bugzilla.clamav.net/show_bug.cgi?id=12048
- Restore exit code compatibility of freshclam with versions before
  0.100.0 when the virus database is already up to date
  (bsc#1104457, clamav-freshclam-exit.patch).
* Tue Jul 31 2018 max@suse.com
- bsc#1101654: Disable YARA support for licensing reasons
  (clamav-disable-yara.patch).
- Do not ignore errors from useradd et al.
- Unclutter the spec file.
* Wed Jul 25 2018 mpluskal@suse.com
- Update dendencies (pcre2, libjson-c and systemd)
- Modernise spec file with spec-cleaner
* Tue Jul 17 2018 security@suse.com
- fix library-without-ldconfig warnings on libclammspack
* Tue Jul 10 2018 egdfree@opensuse.org
- Update to version 0.100.1
  * CVE-2018-0360: HWP integer overflow, infinite loop
    vulnerability (bsc#1101410)
  * CVE-2018-0361: PDF object length check, unreasonably long time
    to parse relatively small file (bsc#1101412)
  * Buffer over-read in unRAR code due to missing max value checks
    in table initialization
  * Libmspack heap buffer over-read in CHM parser
  * PDF parser bugs
  * Add HTTPS support for clamsubmit
  * Fix for DNS resolution for users on IPv4-only machines where
    IPv6 is not available or is link-local only
* Thu Apr 26 2018 max@suse.com
- Update to version 0.100.0 (bsc#1089502):
  * Add interfaces to the Prelude SIEM open source package for
    collecting ClamAV virus events.
  * Support libmspack internal code or as a shared object
    library. The internal library is the default and includes
    modifications to enable parsing of CAB files that do not
    entirely adhere to the CAB file format.
  * Link with OpenSSL 1.1.0.
  * Deprecate of the AllowSupplementaryGroups parameter
    statement in clamd, clamav-milter, and freshclam.
    Use of supplementary is now in effect by default.
  * Deprecate internal LLVM code support.
  * Compute and check PE import table hash (a.k.a. "imphash")
    signatures.
  * Support file property collection and analysis for MHTML files.
  * Raw scanning of PostScript files.
  * Fix clamsubmit to use the new virus and false positive
    submission web interface.
  * Optionally, flag files with the virus
    "Heuristic.Limits.Exceeded" when size limitations are exceeded.
  * Improved decoders for PDF files.
  * Reduced number of compile time warnings.
  * Improved support for C++11.
  * Improved detection of system installed libraries.
  * Fixes to ClamAV's Container system and the introduction of
    Intermediates for more descriptive signatures.
  * Improvements to clamd's On-Access scanning capabilities
    for Linux.
  * Obsoletes clamav-fix_newer_zlib.patch
- Update key ring and add signature file.
- Turn off LLVM for now, because the bundled copy is deprecated,
  the versions we have are too new and the performance gain over
  the  byte code interpreter are negligable, according to upstream.
- Move pkgconfig stuff from main to devel package.
- Re-introduce removed options as deprecated, so that clamd and
  freshclam don't exit on startup with an old config file
  (clamav-obsolete-config.patch).
- Put libclammspack0 into its own subpackage to follow the letter
  of the shlib packaging policy, even though it really makes no
  sense here.
* Wed Mar  7 2018 max@suse.com
- Update to security release 0.99.4 (bsc#1083915):
  * CVE-2012-6706 (bsc#1045315)
  * CVE-2017-6419 (bsc#1052449)
  * CVE-2017-11423 (bsc#1049423)
  * CVE-2018-1000085 (bsc#1082858)
  * CVE-2018-0202 (bsc#1083915)
- Obsolete patches:
  * clamav-CVE-2012-6706.patch
  * clamav-gcc47.patch
* Wed Feb 14 2018 max@suse.com
- bsc#1045490, CVE-2012-6706: VMSF_DELTA filter in libclamunrar
  allows arbitrary memory write (clamav-CVE-2012-6706.patch).
- Buildrequire curl-devel to enable clamsubmit.
* Tue Feb 13 2018 varkoly@suse.com
- bsc=983938 `After=syslog.target` left-overs in several unit files
* Fri Jan 26 2018 vcizek@suse.com
- Update to security release 0.99.3 (bsc#1077732)
  * CVE-2017-12376 (ClamAV Buffer Overflow in handle_pdfname Vulnerability)
  * CVE-2017-12377 (ClamAV Mew Packet Heap Overflow Vulnerability)
  * CVE-2017-12379 (ClamAV Buffer Overflow in messageAddArgument Vulnerability)
  - these vulnerabilities could have allowed an unauthenticated,
    remote attacker to cause a denial of service (DoS) condition
    or potentially execute arbitrary code on an affected device.
  * CVE-2017-12374 (ClamAV use-after-free Vulnerabilities)
  * CVE-2017-12375 (ClamAV Buffer Overflow Vulnerability)
  * CVE-2017-12378 (ClamAV Buffer Over Read Vulnerability)
  * CVE-2017-12380 (ClamAV Null Dereference Vulnerability)
  - these vulnerabilities could have allowed an unauthenticated,
    remote attacker to cause a denial of service (DoS) condition on an affected device.
  * CVE-2017-6420 (bsc#1052448)
  - this vulnerability allowed remote attackers to cause a denial of service
    (use-after-free) via a crafted PE file with WWPack compression.
  * CVE-2017-6419 (bsc#1052449)
  - ClamAV allowed remote attackers to cause a denial of service
    (heap-based buffer overflow and application crash) or possibly
    have unspecified other impact via a crafted CHM file.
  * CVE-2017-11423 (bsc#1049423)
  - The cabd_read_string function in mspack/cabd.c in libmspack 0.5alpha
    allowed remote attackers to cause a denial of service
    (stack-based buffer over-read and application crash) via a crafted CAB file.
  * CVE-2017-6418 (bsc#1052466)
  - ClamAV 0.99.2 allowed remote attackers to cause a denial
    of service (out-of-bounds read) via a crafted e-mail message.
- drop clamav-0.99.2-openssl-1.1.patch (upstream)
* Tue Nov 28 2017 meissner@suse.com
- clamav-0.99.2-openssl-1.1.patch: fixed build against openssl 1.1
* Tue Sep  5 2017 jengelh@inai.de
- Implement shared library guideline.
* Mon Aug 21 2017 fvogt@suse.com
- Add clamav-fix_newer_zlib.patch from ubuntu packages to fix build with
  zlib 1.2.11 (boo#1041201)
* Tue Aug  1 2017 ro@suse.de
- pass --disable-zlib-vcheck to fix build in factory
* Mon May 29 2017 astieger@suse.com
- provide and obsolete clamav-nodb to trigger it's removal in Leap
  bsc#1040662
* Thu Oct 13 2016 fweiss@suse.com
- Add enable-timestamps option to disable time
  dependent macros if passed to configure.
  (bsc#1001154, clamav-disable-timestamps.patch)
* Wed Aug  3 2016 max@suse.com
- boo#991812: Remove obsolete dependency on latex2html-pngicons.
* Thu Jul 21 2016 jengelh@inai.de
- Trim useless words from description and fix spellos.
  Test for user/group existence before adding and always show
  errors when they occur.
* Thu Jun 30 2016 fweiss@suse.com
- Added BuildRequires systemd-rpm-macros
- Added %%ghost entry for /run/clamav
- Use /run instead of /var/run because it is a symlink nowadays
  (clamav-tmpfiles.conf)
* Thu Jun 23 2016 fweiss@suse.com
- Update to version 0.99.2 (bsc#978459)
  * 7z: fix for FolderStartPackStreamIndex array index heck
  * print all CDBNAME entries for a zip file when using the -z
    flag.
  * try to minimize the err cleanup path
  * clamunrar: notice if unpacking comment failed
  * signature manual update.
  * use temp var for realloc to prevent pointer loss.
  * fix debug VI hex truncation
  * freshclam: avoid random data in mirrors.dat.
  * libclamav: print raw certificate metadata
  * freshclam manager check return code of strdup.
  * additional suppress IP notification when using proxy
  * fix download and verification of *.cld through PrivateMirrors
  * suppress IP notification when using proxy
  * remove redundant mempool assignment
  * divide out dumpcerts output for better readability
  * fix dconf and option handling for nocert and dumpcert
  * patch by Jim Morris to increase clamd's soft file descriptor to
    its potential maximum on 64-bit systems
  * Move libfreshclam config to m4/reorganization.
  * adding libfreshclam
  * Add 'cdb' datafile to sigtools list of datafile types.
  * NULL pointer check.
  * malloc() NULL pointer check.
  * clamscan 'block-macros' option.
  * initialize cpio name buffer
  * initialize mspack decompression buffers
  * prevent memory allocations on used pointers (folder objects)
  * prevent memory allocations on used pointers (boolvectors)
  * initialize ARJ metadata structures
  * change cli_malloc with cli_calloc
  * check packSizes prior to dereference
  * fixed inconsistent folder state on failure
  * pre-check on (*unpackSizes) dereference
  * fix on pre-checks on dereferenced array
  * pre-checks on dereferenced array size values (not =0)
  * adding sanity checks to 7z header parsing
  * fixed mew source read issue
  * documentation update on targets
  * filetype consistency
  * move llvm option flag handling to new m4 file
  * hwp5.x: fix for streams without names
- bsc#958451: Remove updateclamconf, because it breaks
  configurations that have multiple occurances of the same keyword.
  Henceforth the configuration files have to be merged manually, if
  a ClamAV update adds or removs options.
* Fri Jun 17 2016 martin.liska@suse.com
- Change default C++ std to -std=gnu++98.
* Thu Mar  3 2016 ecsos@opensuse.org
- Update to version 0.99.1 (bsc#969814)
  * hwp5.x: fix for streams without names
  * libclamav: yara: avoid unaliged access to 64bit variable
  * patch by Mark Allan to add show-progress option to freshclam.
  * added 'CustomXML' as trigger for likely OOXML
  * ClamAV 0.99.1 beta1 release.
  * add scanning options for scanning xml-based documents
  (MSXML, OOXML, HWPML) and HWP3
  * add dconfs for XDP, MBR, GPT, APM, OOXML, MSXML, and HWP formats
  * hwp: scan decompressed data on limits exceeded
  * Fix for signature name length<3 in .ign & .ign2 CVD files.
  * Change RTF file magic from '{\rtf' to '{\rt'
  * zeroing out buffer at allocation to avoid writing uninitialized
  bytes to a file
  * adding check for compressed input stream
  * clean up and boost accuracy to detecting OOXML documents
  * Fix crash when using pcre statistics due to inconsistent memory
  management function calls
  * adding check to verify a valid number of rounds for rijndael aes
  encryption/decryption
  * fixing edge case revealed by unit testing
  * let html be scanned raw when --scan-html=no is in effect.
  * fix crash due to memory overlay with crafted 7z files.
  * fixing off by one OOB write in htmlnorm
  * fixing autoit OOB bufferread
  * sigtool: adding support for decoding cdb sigs
  * fix embedded http links.
  * fix regression crash on sid 1005597703 due to uninitialzed
  (i.e., garbage initialized) structure.
  * corrects mso stream prefix value for big endian processors.
  * ooxml_hwp: add support for filetyping and preclassification
  * hwpole2: new filetype and handler for hwp embedded ole2 files
  * fixing possible oob dereference when parsing mbox files
  * adding explicit wwunpack oob checks
  * fixing edge case where a null terminator was unintentionally
  written into an adjacent buffer.
  * hwpml: use msxml_parser callback scanner for binary data
  * msxml_parser: add callback-based scanning mechanism
  * HWPML: added hwpml_keys for hwpml parsing
  * add HMPML filetype, tab fixes in filetype.c
  * Hwp3.x: inflate compressed segment and offset tracking
  * Hwp3.x file header parsing and preclass
  * pcre: fixed minimum pcre version check
  * fix detection of libcheck without pkg-config file
  * add HWP5 filetype tracking to preclassification
  * add HWP 3.x internal filetypes
  * add hwp5 contents to preclass set
  * proper identification of HWP file format
  * strengthen file typing for OOXML.
  * normalization of whitelist signatures
  * github issue #9 - wrong length & offset.
* Fri Dec 25 2015 meissner@suse.com
- now can handle regexp using signatures using pcre bsc#960237
* Thu Dec  3 2015 max@suse.com
- Version 0.99 fixes bsc#957728.
* Wed Dec  2 2015 p.drouand@gmail.com
- Update to version 0.99
  * Processing of YARA rules(some limitations- see signatures.pdf).
  * Support in ClamAV logical signatures for many of the features
    added for YARA, such as Perl Compatible Regular Expressions,
    alternate strings, and YARA string attributes. See signatures.pdf
    for full details.
  * New and improved on-access scanning for Linux. See the recent blog
    post and clamdoc.pdf for details on the new on-access capabilities.
  * A new ClamAV API callback function that is invoked when a virus
    is found. This is intended primarily for applications running in
    all-match mode. Any applications using all-match mode must use
    the new callback function to record and report detected viruses.
  * Configurable default password list to attempt zip file decryption.
  * TIFF file support.
  * Upgrade Windows pthread library to 2.9.1.
  * A new signature target type for designating signatures to run
    against files with unknown file types.
  * Improved fidelity of the "data loss prevention" heuristic
    algorithm. Code supplied by Bill Parker.
  * Support for LZMA decompression within Adobe Flash files.
  * Support for MSO attachments within Microsoft Office 2003 XML files.
  * A new sigtool option(--ascii-normalize) allowing signature authors
    to more easily generate normalized versions of ascii files.
  * Windows installation directories changed from \Program Files\Sourcefire\
    ClamAV to \Program Files\ClamAV or \Program Files\ClamAV-x64.
- Refactor a little the specfile; remove some obsolete conditional
  macros, as clamav doesn't build for SLE11 anyway
- Remove clamav-sles9.patch; sles9 is not supported for a while
* Wed Jul  1 2015 mpluskal@suse.com
- Make clamd and clamav-milter services depend on freshclam as
  they need it
* Mon May  4 2015 max@suse.com
- Version 0.98.7 fixes several security issues (bsc#929192) and
  other bug fixes/improvements:
  * Fix crash in upx decoder with crafted file. Discovered and
    patch supplied by Sebastian Andrzej Siewior. CVE-2015-2170.
  * Fix infinite loop condition on crafted y0da cryptor
    file. Identified and patch suggested by Sebastian Andrzej
    Siewior. CVE-2015-2221.
  * Fix crash on crafted petite packed file. Reported and patch
    supplied by Sebastian Andrzej Siewior. CVE-2015-2222.
  * Fix an infinite loop condition on a crafted "xz" archive file.
    This was reported by Dimitri Kirchner and Goulven Guiheux.
    CVE-2015-2668.
  * Apply upstream patch for possible heap overflow in Henry
    Spencer's regex library. CVE-2015-2305.
  * Fix false negatives on files within iso9660 containers. This
    issue was reported by Minzhuan Gong.
  * Fix a couple crashes on crafted upack packed file. Identified
    and patches supplied by Sebastian Andrzej Siewior.
  * Fix a crash during algorithmic detection on crafted PE file.
    Identified and patch supplied by Sebastian Andrzej Siewior.
  * Fix compilation error after ./configure --disable-pthreads.
    Reported and fix suggested by John E. Krokes.
  * Fix segfault scanning certain HTML files. Reported with sample
    by Kai Risku.
  * Improve detections within xar/pkg files.
  * Improvements to PDF processing: decryption, escape sequence
    handling, and file property collection.
  * Scanning/analysis of additional Microsoft Office 2003 XML
    format.
* Thu Feb  5 2015 max@suse.com
- Version 0.98.6 fixes several security issues:
  * bsc#916217, CVE-2015-1461: Remote attackers can have
    unspecified impact via Yoda's crypter or mew packer files.
  * bsc#916214, CVE-2015-1462: Unspecified impact via acrafted upx
    packer file.
  * bsc#916215, CVE-2015-1463: Remote attackers can cause a denial
    of service via a crafted petite packer file.
  * bsc#915512, CVE-2014-9328: heap out of bounds condition with
    crafted upack packer files.
- Obsoletes clamav-soname.patch
* Fri Jan 30 2015 max@suse.com
- Don't need sendmail for building clamav-milter anymore,
  sendmail-devel is enough (bnc#915414).
* Fri Jan 23 2015 max@suse.com
- bnc#914505: Config file merging and temp file creation got moved
  to %%pre by mistake. Put them back to %%post.
- Restore the updateclamconf script (bnc#908731).
- Fix a step backwards in the soname version from 0.98.4 to 0.98.5
  (https://bugzilla.clamav.net/show_bug.cgi?id=11193,
  clamav-soname.patch).
* Thu Jan  1 2015 meissner@suse.com
- build with PIE
* Wed Nov 19 2014 max@suse.com
- Version 0.98.5:
  * Support for the XDP file format and extracting, decoding, and
    scanning PDF files within XDP files.
  * Addition of shared library support for LLVM versions 3.1 - 3.5
    for the purpose of just-in-time(JIT) compilation of ClamAV
    bytecode signatures.
  * Enhancements to the clambc command line utility to assist
    ClamAV bytecode signature authors by providing introspection
    into compiled bytecode programs.
  * Resolution of many of the warning messages from ClamAV
    compilation.
  * Improved detection of malicious PE files.
    (bnc#906770, CVE-2014-9050)
  * Security fix for ClamAV crash when using 'clamscan -a'.
  * Security fix for ClamAV crash when scanning maliciously
    crafted yoda's crypter files (bnc#906077, CVE-2013-6497).
  * ClamAV 0.98.5 now works with OpenSSL in FIPS compliant
    mode (bnc#904207).
  * Fix server socket setup code in clamd (bnc#903489).
- Change updateclamconf to prefer the state of the old config
  file even for commented-out options (bnc#903719).
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Thu Jun 26 2014 max@suse.com
- Version 0.98.4:
  * Fix infinite loop in clamdscan when clamd is not running.
  * Fix buffer underruns when handling multi-part MIME email
    attachments.
  * Fix onfiguration of OpenSSL on various platforms.
  * Fix linking issues with libclamunrar.
* Thu Jun 12 2014 max@suse.com
- Fix dangling symlink in documentation (bnc#872682).
- Remove init scripts and complete systemd integration.
- Remove %%ghost entry for /var/run/clamav.
* Thu May  8 2014 max@suse.com
- Version 0.98.3:
  * Support for common raw disk image formats using 512 byte
    sectors, specifically GPT, APM, and MBR partitioning.
  * Experimental support of OpenIOC files. ClamAV will now extract
    file hashes from OpenIOC files residing in the signature
    database location, and generate ClamAV hash signatures. ClamAV
    uses no other OpenIOC features at this time. No OpenIOC files
    will be delivered through freshclam. See openioc.org and
    iocbucket.com for additional information about OpenIOC.
  * All ClamAV sockets (clamd, freshclam, clamav-milter, clamdscan,
    clamdtop) now support IPV6 addresses and configuration
    parameters.
  * Use OpenSSL file hash functions for improved performance.
    OpenSSL is now prerequisite software for ClamAV 0.98.3.
  * Improved detection of malware scripts within image files.
  * Change to circumvent possible denial of service when processing
    icons within specially crafted PE files. Icon limits are now in
    place with corresponding clamd and clamscan configuration
    parameters. This issue was reported by Joxean Koret.
  * Improvements to the fidelity of the ClamAV pattern matcher, an
    issue reported by Christian Blichmann.
  * Opt-in collection of statistics. Statistics collected are:
    sizes and MD5 hashes of files, PE file section counts and
    section MD5 hashes, and names and counts of detected
    viruses. Enable statistics collection with the --enable-stats
    clamscan flag or StatsEnabled clamd configuration parameter.
  * Improvements to ClamAV build process, unit tests, and platform
    support.
  * Improve error handling in freshclam.
  * ClamAV 0.98.3 also includes miscellaneous bug fixes and
    documentation improvements.
- clamav-fan-syscalls.patch isn't needed anymore because ClamAV
  now uses sys/fanotify.h .
* Wed Apr 23 2014 dmueller@suse.com
- do not disable security checks in configure. That would be
  insecure
- use DFP_64bit also for aarch64
* Thu Mar 13 2014 boris@steki.net
- initial systemd support unit files
* Wed Feb 19 2014 meissner@suse.com
- add fanotify systemcalls for power, s390 and arm
* Tue Feb  4 2014 max@suse.com
- Improve handling of /var/run/clamav.
* Fri Jan 24 2014 max@suse.com
- Version 0.98.1 (bnc#841815):
  * remove copy of wxWidgets (halves the size of the tarball).
  * Decompression and scanning of files in "Xz" compression
    format.
  * Extraction, decompression, and scanning of files within Apple
    Disk Image (DMG) format.
  * Extraction, decompression, and scanning of files within
    Extensible Archive (XAR) format.  XAR format is commonly used
    for software packaging, such as PKG and RPM, as well as
    general archival.
  * Improvements and fixes to extraction and scanning of ole
    formats.
  * Option to force all scanned data to disk.
  * Various improvements to ClamAV configuration, support of third
    party libraries, and unit tests.
- Rediff clamav-conf.patch
* Sun Dec 15 2013 uweigand@de.ibm.com
- fix build failures on ppc64le:
  * fanotify is only supported on x86 platforms
  * building tomsfastmath on (non-x86) 64-bit platforms requires -DFP_64BIT
* Sat Sep 28 2013 meissner@suse.com
- Version 0.98 (bnc#841815)
  * code quality fixes on libclamav, clamd, sigtool, clamav-milter, clamconf and clamdtop
  * code quality fixes on libclamav, libclamunrar and freshclam
  * valgrind suppression rules for dl_catch_error complaints
  * bb #8385: PDF ASCII85Decode zero-length fix
  * libclamav: SCAN_ALL mode fixes
  * bb #7436: elf64 header early exit
  * iso9660: iso_scan_file rewrite
- use source urls, add gpg signature retrieval.
* Mon Apr 29 2013 meissner@suse.com
- mirror the amavisd-new change of /var/spool/amavis bnc#663726
* Sun Apr 28 2013 ecsos@schirra.net
- Version 0.97.8 (bnc#816865)
  * libclamav: Bugs reported by Felix Groebert of the Google Security Team
* Wed Mar 20 2013 max@suse.com
- Version 0.97.7 (bnc#809945)
  * several hardening fixes.
* Mon Jan 14 2013 mmeister@suse.com
- pids and sockets of clamd and freshclam now reside in /var/run
  instead of /var/lib (bnc#770395)
- modified pid path in clamd's, freshclam's and clamav-milter's
  init scripts
* Mon Jan  7 2013 max@suse.com
- Remove the clamav-db subpackage. ClamAV installations should
  fetch current versions of the virus database directly from
  upstream. If there really is need for a packaged database, it
  should be in a separate package.
- Remove scripts do deal with very old (before 2008) config and
  database file formats.
* Sat Jan  5 2013 andreas.stieger@gmx.de
- update daily.cvd to ver. 16364
  released on 04 Jan 2013 20:37 :0500 (sig count: 492103)
- add cvd signature verification to %%check section
- make Release field of clamav-db package contain cvd file versions
* Fri Sep 28 2012 max@suse.com
- 0.97.6 also fixes bnc#780181.
* Wed Sep 19 2012 toganm@opensuse.org
- update to 0.97.6
  * libclamav: bb#5751 - cl_scansis() may returan a file descriptor
    instead of a valid return code
* Thu Jul 26 2012 dmueller@suse.com
- avoid make check on qemu build
* Thu Jun 21 2012 max@suse.com
- The CVEs below correspont to: bnc#753611, bnc#753613, bnc#753610.
* Tue Jun 19 2012 andreas.stieger@gmx.de
- update to 0.95.5 [bnc#767574]
- addresses possible evasion cases in some archive formats
- CVE-2012-1457: allows to bypass malware detection via a TAR archive
  entry with a length field that exceeds the total TAR file size
- CVE-2012-1458: allows to bypass malware detection via a crafted
  reset interval in the LZXC header of a CHM file
- CVE-2012-1459: allows to bypass malware detection via a TAR archive
  entry with a length field corresponding to that entire entry, plus
  part of the header of the next entry
- also addresses stability issues in portions of the bytecode engine
- update clamav-conf.patch for moved lines
- add a definitions snapshot as {main,daily}.cvd no longer in tarball
- fix file-contains-date-and-time rpmlint warning
* Sat Mar 17 2012 dimstar@opensuse.org
- Add clamav-gcc47.patch: Fix build with gcc 4.7.
* Sat Mar 17 2012 toganm@opensuse.org
- New version 0.97.4
  * libclamav/bytecode.c: reset to BYTECODE_AUTO mode at db reload
  so that we don't fail to re-enable or re-disable it again
  (bb#3789)
  * misc: performance improvement for HP-UX PA-RISC - patch from
  Michael Pelletier <michael.v.pelletier*raytheon.com>
  (bb#3926)
  * libclamav/pe.c: parse vinfo where varfileinfo occours before
  stringfileinfo (bb#3062)
  * clamd: add support for on-access scanning on OS X with ClamAuth
  (beta)
  * libclamav/bytecode_api*: Fix Sparc crash (bb #4324)
  * libclamav: fix bytecode whitelisting
  * libclamav: fix macro detection in OLE2BlockMacros (bb#4269)
  * libclamav/readdb.c: allow comments in all db files (bb#3930)
  * libclamav/scanners.c: use lsigs when scanning vba data (bb#3922)
  * libclamav/matcher-hash.c: Fix SIGBUS on PA-RISC (big-endian)
  architectures (bb #3894).
* Tue Oct 18 2011 max@suse.com
- New version 0.97.3 (bnc#724856, CVE-2011-3627):
  * freshclam/manager.c: fix error when compiling without DNS
    support (bb#3056)
  * libclamav/pdf.c: flag and dump PDF objects with /Launch
    (bb #3514)
  * libclamav/bytecode.c,bytecode_api.c: fix recursion level crash
    (bb #3706).
  * docs: clarify behavior of --scan-*/Scan* options (bb#3134)
  * libclamav/bytecode_vm.c: fix opcode 20 error (bb #3100)
  * freshclam: fix pidfile removal (bb#3499)
  * libclamav/pdf.c:  fix incorrect blocking of some encrypted PDF
    with empty user passwords. (bb #3364)
  * sigtool/sigtool.c: fix calculation of max signature length
* Tue Jul 26 2011 max@novell.com
- New version 0.97.2 (bnc#708263):
  * libclamav/matcher-hash.c: off by one read in cli_hm_scan
    (bb#2818, CVE-2011-2721).
  * libclamav/pdf.c: fix encrypted pdf detection (bb #2988)
  * clamav-milter/clamfi.c: fix typo in error message (bb#3040)
  * libclamav/lzma_iface.c: shut up huge alloc warns for 7z/lzma
    (bb#2913)
  * libclamav/c++/bytecode2llvm.cpp: fix use of unaddressable data
    in bytecode_watchdog.
  * libclamav/phishcheck.c: fix safebrowsing detection on certain
    URLs
* Thu Jun  9 2011 max@novell.com
- New version 0.97.1 (bnc#698999):
  * libclamav/mew.c: harden boundary check on e8/e9 fixup
  * libclamav/matcher-hash.c: in hm_sort don't swap an item with
    itself (bb#2818)
  * freshclam/manager.c: fix return code of Rfc2822DateTime()
    (bb#2809)
  * libclamav/pdf.c: better detection for encrypted PDFs
    (bb #2448)
  * libclamav/c++: add support for building with external LLVM 2.9,
    and drop external 2.8 support
  * clamd: log request ip address for instream scans #bb2592
  * libclamav/c++/llvm/lib/Target/X86/X86InstrInfo.td: bb #2763
    don't assert on AVX chips (Intel Core i5 and i7)
  * sigtool: properly normalize html files (bb#2764)
  * sigtool/sigtool.c: fix formatting of hash dbs (bb#2765)
  * freshclam: add mirror statistics mechanism
  * libclamav/pe_icons.c: don't sigbus on sparc (bb#2695)
  * libclamav/pe.c: reset corrupted status before bytecode
    hooks (bb#2544)
  * sigtool, freshclam: put .info on top of container to speed
    up loading
  * sigtool: fix --verify-cdiff
  * sigtool: allow arbitrary names for --build
  * clamdscan: fix file exclusion (bb#2579)
  * clamd: add new option ClamukoExcludeUID (bb#2260)
  * libclamav/elf.c: fix incorrect detection of Broken.Executable
    (bb#2580)
  * shared/output.c: fix empty lines in syslog (bb#2578)
  * clamd: update description of ReadTimeout (bb#2565)
  * clamd: add new config option BytecodeUnsigned (bb#2537);
    drop "None" from BytecodeSecurity
  * clamscan: add new switch --bytecode-unsigned and drop
  - -bytecode-trust-all
  * sigtool/sigtool.c: improve handling of bytecode.info (bb#2292)
  * libclamav/others.c: make sure TLS key is initializer
    (bb #2588).
  * configure: check for enable_extended_FILE_stdio (bb #2542)
  * sigtool/sigtool.c: handle all signature formats with
  - -(list|find)-sigs (bb#2534)
* Wed Feb  9 2011 max@novell.com
- Security update 0.9.7 (bnc#673753):
  ClamAV 0.97 brings many improvements, including complete Windows
  support, support for signatures based on SHA1 and SHA256, better
  error detection, as well as speed and memory optimizations. The
  complete list of changes is available in the ChangeLog file. For
  upgrade notes and tips please see:
  https://wiki.clamav.net/Main/UpgradeNotes097
* Wed Dec  1 2010 max@novell.com
- New version 0.96.5 (bnc#656548):
  * libclamav/pdf.c: fix crashes (bb #2358, bb #2380, bb #2396).
  * libclamav/pe_icons.c: off by one while (bb#2344)
  * libclamav: fix detection of embedded executables
  * libclamav/matcher-ac.c: fix offset handling for sigs with {x-y}
  * freshclam/manager.c: fix error path infinite loop (bb#2389)
  * freshclam: improve mirror management
  * libclamav: fix possible use of uninitialized values (bb#2291)
  * libclamav: Set the unreliability flag on (un)packed files
    (bb#2307)
  * libclamav/c++: Update embedded copy of LLVM to version 2.8
    (bb #2327)
  * freshclam: make query format backward compatible
  * freshclam: get detection stats directly from clamd (bb#2312)
  * libclamav/cache.c,c++/bytecode2llvm.cpp}: make cl_load thread
    safe (bb #2333).
  * freshclam: load database in subprocess (bb #2147).
  * clamd: add new commands DETSTATS and DETSTATSCLEAR
    (part of bb#2312)
  * libclamav/7z.c: fix file descriptor leak (bb #2347)
  * clamd, libclamavll: add ability to logg messages from libclamav
    (bb #1965)
  * libclamav/builtin_bytecodes.h: Don't disable JIT on pentium4
    (bb #2345)
  * clamav-for-windows: displace clamav-for-windows to a separate
    solution and directory
  * clamd: add new option OLE2BlockMacros (requested by Mike)
  * freshclam: DatabaseCustomURL: add support for
    If-Modified-Since
  * freshclam: add initial support for DatabaseCustomURL
* Thu Oct 28 2010 max@suse.de
- New version: 0.96.4 (bnc#649631):
  * sigtool/sigtool.c: don't use of sizeof() for malloc'ed buffer
    (bb#2283)
  * shared/cdiff.c, sigtool/sigtool.c: fix error path double frees
    (bb#2280, bb#2281)
  * See /usr/share/doc/packages/clamav/ChangeLog for the full list
    of changes.
* Wed Sep 22 2010 max@novell.com
- New version: 0.96.3 (bnc#640812):
  * libclamav/nsis/bzlib.cld sys: port upstream fixes for
    CVE-2010-0405, check for buggy bzip2 (bb#2230, bb#2231).
  * libclamav/pdf.c: Add missing boundscheck to pdf code
    (bb #2226).
  * libclamav/c++/bytecode2llvm.cpp: workaround crash due to gcc
    stack alignment requirements (bb #2270).
  * libclamav/pdf.c, pe.c, bytecode*: Fix bytecode virusname
    reporting (bb #2255).
  * clamav-milter/netcode.c: fix error path fd leak when
    connection succeeds but ping fails (bb#2259).
  * libclamav/bytecode.c: properly skip bytecodes with long lines.
  * unit_tests: add VI unit tests
  * libclamav: versioninfo hashset was not properly cached
    (bb#2065).
  * libclamav/pe.c: add BC_PE_ALL hook (bb #2237).
  * libclamav/c++/{bytecode2llvm,ClamBCRTChecks}.cpp: avoid false
    'Verification error' messages (bb #2239).
  * freshclam/freshclam.c: fix handling of relative paths with
  - -datadir (bb#2240).
  * clamd/clamd.c: limit RLIMIT_DATA to 2GB on 32-bit processes
    (bb #1941).
  * libclamav/regex/regexec.c: fix regex when
    sizeof(void*) != sizeof(long) (bb #2232).
  * libclamav/pdf.c: improve handling of pdf objects (bb #2216).
  * libclamav/pe_icons.c: support special case where icon is
    encoded as 32bpp but it really carries alpha as a mask... well
    go figure. (bb#2221)
  * libclamav/mpool.c: permanently disable debug mode (bb#2222).
  * libclamav: allow logical sigs to be used as file type sigs
    (bb#2228).
  * libclamav/c++/detect.cpp: don't warn on x86_64 vs i386
    mismatches (bb #2214).
  * sigtool/sigtool.c: fix EOL matching in --find-sigs (bb#2164).
  * libclamav/bytecode_detect.c: prevent fclose(NULL) on SELinux
    (bb #2200).
* Wed Sep 15 2010 max@suse.de
- BuildRequire python-devel instead of python, so that we get the
  unittest module needed for "make check".
* Mon Aug 16 2010 max@suse.de
- New version: 0.96.2
- This version brings a new PDF parser, performance and memory
  improvements, and a number of bugfixes and minor enhancements.
  This upgrade is recommended for all users.
* Wed May 19 2010 max@suse.de
- New version: 0.96.1:
  * libclamav/7z/Archive/7z/7zIn.c: fix possible(?) null dereference
  reported by clang (bb#1909).
  * libclamav/pe_icons.c: properly round down when scaling (bb#2031)
  * libclamav/pdf.c: bb #2016
  * libclamav/readdb.c: properly reject .info files passed on
  cmdline (bb#2025)
  * libclamav/matcher-bm.c: fix offset check (bb#2032)
  * libclamav/fmap.c: fix bug introduced in clamav-0.96-51-g3e3b587.
  * libclamav/pe.c: properly resume stringtable loop (bb#2027)
  Note: 0.96 is NOT affected as the min VI sig has got FL=53
  * unit_tests: add bytecode.cvd load test
  * docs/man: add clamav.milter.conf.5
  * libclamav: Use mpool in win32 (well, sort of) as the mighty crt
  allocator
  * libclamav/fmap.c: make oof need stfu (bb#2000)
  * libclamav/bytecode.c: handle global gep parameter correctly (bb
  [#1955])
  * libclamav/c++/llvm: Update to LLVM 2.7 release.
  * libclamav/bytecode*, unit_tests: add new unit tests for bytecode
  API and fix bugs.
  * libclamav/c++: Relax bounds checks. Was rejecting correct code.
  * libclamav/filtering.c: fix handling of alternates and negated
  alternates (bb #2004)
  * libclamav/readdb.c: read the entire .cbc files, fix loading of
  bytecode.cvd
  * freshclam: fix handling of temporary files
  * freshclam: add new option TestDatabases
  * tools: make sure the libclamav version is high enough (bb#2013)
  * sigtool/sigtool.c: fix error msg (bb#2002)
  * clamdscan: respect ExcludePath in --fdpass mode (bb#1923)
  * libclamav/c++/llvm/test: Fix make check failure on x86-32 (bb
  [#1942])
  * clamdscan: respect ExcludePath in --fdpass mode (bb#1923)
  * libclamav/readdb.c: add checks to enforce lsig compatibility
  with 0.95.x (bb# 2008)
  * clamscan/manager.c: don't closedir(NULL) (bb #2010)
  * libclamav/c++/configure: add check that correct libstdc++
  version is used (bb #1971)
  * libclamav/cache.c: support building without pthreads (bb #1897).
  * libclamav/bytecode*: add match_offsets support.
  * shared/output.c: workaround FreeBSD's file locking issue
  (bb#1918)
  * freshclam/notify.c: fix warning message (bb#1972)
  * libclamav: make lsigs working in cli_scanscript() (bb#1998)
  * libclamav/fmap.c: nicely handle EINTR
  * libclamav: no ERROR on void mapping (bb#1968)
  * libclamav/matcher-ac.c: fix counting of subsig matches (bb#2001)
  * clamav-milter: add VirusAction (bb#1867)
  * libclamav/c++/llvm/include/llvm/ADT/SmallVector.h: Fix crash
  with -ftree-vectorize/-O3(bb #1984).
  * libclamav: fix some limit settings (bb#1973)
  * bytecode: min/max functionality level support.
  * libclamav/others.c: bump f-level
  * libclamav/matcher-ac.c: fix handling of VI/MACRO special offsets
  (bb#1957)
  * configure: fix Apple-style universal build (bb #1988).
  * libclamav/fmap.c: downgrade warning when the kernel doesn't want
  a map back
  * libclamav: avoid loading duplicate databases (bb#1962)
  * clamconf: print information about platform and build.
  * libclamav/c++/configure: disable gcc 3.4.6 by default, you can
  still use it with --enable-llvm (bb #1935).
  * docs/man/freshclam.conf.5.in: document LogFileMaxSize (bb#1960)
  * freshclam/manager.c: add support for X-HostID to allow custom
  UserAgent
  * libclamav/bytecode.c: fix cli_unlink warnings (bb #1956).
  * clambc, clamd,clamdtop,libclamav,unit_tests: fix compiler
  warnings (bb #1872,
  * libclamav/c++: allow building with gcc 3.4.6 (bb #1934).
  * unit_tests/check_common.sh: fix make check on AIX (bb #1917).
  * freshclam/manager.c: better handle daylight saving time changes
  (bb#1920)
  * libclamav/pe.c: more relaxed vinfo parser - try to mimic winxp's
  * sigtool: handle .idb files
  * libclamav/matcher.c: return proper virus name in icon detector
  (bb#1933)
  * libclamav/c++/bytecode2llvm.cpp: Fix load of multiple unsigned
  bytecodes (bb #1924)
  * contrib/split-tarball.sh: update to work with 0.96
  * libclamav/Makefile.{am,in}: Fix unit test failure with
  non-English locale (bb #1922)
  * libclamav/c++/llvm/lib/Support/Allocator.cpp: Fix
  SpecificBumpPtrAllocator destructor iteration.
  * libclamav/c++/llvm/lib/ExecutionEngine/JIT/JIT.cpp: Fix the
  previous PowerPC workaround to not crash when not using the JIT.
  * libclamav/c++/{bytecode2llvm.cpp,llvm/lib/ExecutionEngine/JIT/JIT.cpp,
  llvm/lib/Target/PowerPC/PPCISelLowering.cpp}: Workaround LLVM
  JIT PowerPC relocation bug (bb #1921).
  * unit_tests: Fix matchwithread.cbc
* Wed Apr 14 2010 max@suse.de
- Extended the libmilter compatibility patch for SLES9.
- Explicitly disabling LLVM for versions older than SLES10 and
  archs other than i586 and x86_64.
* Mon Apr 12 2010 max@suse.de
- Leave it up to configure to decide whether the arch supports JIT
  compiling through LLVM (currntly only x86 and x86_64).
* Wed Apr  7 2010 max@suse.de
- ClamAV 0.96 introduces new malware detection mechanisms and
  other significant improvements to the scan engine.
  The key features are:
  * The Bytecode Interpreter: the interpreter built into LibClamAV
    allows the signature writers to create and distribute very
    complex detection routines and remotely enhance the scanner’s
    functionality.
  * Heuristic improvements: improve the PE heuristics detection
    engine by adding support of bogus icons and fake PE header
    information. In a nutshell, ClamAV can now detect malware that
    tries to disguise itself as a harmless application by using
    the most common Windows program icons.
  * Signature Improvements: logical signature improvements to
    allow more detailed matching and referencing groups of
    signatures. Additionally, improvements to wildcard matching on
    word boundaries and newlines.
  * Support for new archives: 7zip, InstallShield and CPIO.
    LibClamAV can now transparently unpack and inspect their
    contents.
  * Support for new executable file formats: 64-bit ELF files and
    OS X Universal Binaries with Mach-O files. Additionally, the
    PE module can now decompress and inspect executables packed
    with UPX 3.0.
  * Support for DazukoFS in clamd
  * Performance improvements: overall performance improvements and
    memory optimizations for a better overall resource utilization
    experience.
* Thu Mar 11 2010 max@suse.de
- New version: 0.96rc1
- Added gcc-c++ to BuildRequires to enable the JIT compiler.
* Tue Feb  9 2010 prusnak@suse.cz
- build -db subpackage as noarch
* Thu Oct 29 2009 max@suse.de
- Bugfix release 0.95.3 (bnc#550929)
- Changes include:
  * Fix various error path leaks.
  * Drop hardcoded offset limits for embedded objects.
  * Fix matching of logical sigs.
  * Fix handling of broken .ldb sigs.
  * Improve handling of PDF files.
  * Work around possible race condition during db updates.
  * Fix detection of encrypted zip files embedded into other files.
  * Properly handle clamd disconnection in clamav-milter.
* Wed Jun 17 2009 max@suse.de
- clamav-sles9.patch: smfi_insheader() doesn't exist in libmilter
  on SLES9, so we revert a recent change that introduced its
  usage to improve the handling of DomainKeys Identified Mail.
* Mon Jun 15 2009 max@suse.de
- Security release: 0.95.2 (bnc#511963).
* Tue Apr 14 2009 max@suse.de
- Security release: 0.95.1 (bnc#493562)
* Mon Apr  6 2009 max@suse.de
- Version 0.95 also fixes two security issues:
  bnc#491935 and bnc#491938.
- Removed unneeded tcpd build dependency.
- Removed obsolete configure switches.
- ncurses-devel is needed for building clamtop.
- Patched clamav-milter up to the latest upstream version to fix
  the non-detection of virus code outside of attachments.
  (bnc#445137)
- Improved rcclamd to print a more instructive message when the
  virus database files are missing.
* Tue Mar 24 2009 max@suse.de
- New version 0.95 (bnc#488317):
  * clamav-milter got rewritten. Standalone mode got dropped and
    using multiple instances of clamd in parallel got added for
    load sharing and fail-safety. The command lin
  * Changes to the libclamav API will make future changes less
    likely, but require adjustment of applications linking to
    libclamav.
  * Numerous other bug fixes and improvements.
  * libGMP is no longer needed.
- Drop support for versions older than 9.1/SLES9.
- Improve init script of clamav-milter (bnc#445137).
* Mon Dec  1 2008 max@suse.de
- New version 0.94.2 fixes recursion limits in JPEG scanning code
  (bnc#450207).
* Tue Nov 11 2008 max@suse.de
- Version 0.94.1 also fixes bnc#443311.
- Disabled valgrind tests again, as they show false positives with
  current glibc.
* Fri Nov  7 2008 max@suse.de
- New bugfix release: 0.94.1:
  * daily.ign was overwriting local.ign
  * vba_extract.c: get_unicode_name off-by-one
  * Don't execute special events twice in interactive mode
  * Fix leak on rare error path in clamd/scanner.c.
  * Fix URL parsing in phishing checks.
  * Improve the javascript scanner.
  * Fixes to bzip2 uncompression.
  * Properly close descriptors before forking in clamav-milter.
  * enable ScanPDF by default
  * Testsuite improvements
  * Many more minor bug fixes.
- Fix pid file format of clamav-milter.
- Improve clamav-milter configuration and init script (bnc#347684).
- Suppressing valgrind error on iconv_open.
* Mon Sep 29 2008 max@suse.de
- Limit valgrind to i586 and x86_64.
* Wed Sep  3 2008 max@suse.de
- Added check-devel and valgrind to BuildRequires for 10.3 and
  newer to support the new unit testing feature. This does not
  add new runtime dependencies.
- New version: 0.94:
  * fix out-of-memory null dereferenc (bb#1141)
  * fix possible invalid memory access (bb#1089)
  * fix error path memleaks and fd leaks (bb#1141)
  * Logical Signatures: The logical signature technology uses
    operators such as AND, OR and NOT to allow the combination
    of more than one signature into one entry in the signature
    database resulting in more detailed and flexible pattern
    matching.
  * Anti-phishing Technology: Users can now change the priority
    and reporting of ClamAV's heuristic anti-phishing scanner
    within the detection engine process.
  * Disassembly Engine: The initial version of the disassembly
    engine improves ClamAV's detection abilities.
  * PUA Detection: Users can now decide which PUA signatures
    should be loaded
  * Data Loss Prevention (DLP): This version includes a new
    module that, when enabled, scans data for the inclusion of
    US formated Social Security Numbers and credit card numbers.
  * IPv6 Support: Freshclam now supports IPv6
  * Improved Scanning of Scripts: The normalization of scripts
    now covers JavaScript
  * Improved QA and Unit Testing: The improved QA process now
    includes API testing and new library of test files in
    various formats that are tested on a wide variety of systems.
* Tue Jul  8 2008 max@suse.de
- New version 0.93.3 (bnc#406994):
  * make sigtool compatible with the new OLE2 scan scheme (bb#1086)
  * add missing checks for recv() failures (bb#1079)
  * add missing check for file open failure (bb #1083).
  * fix handling of nodes which also match single bytes (bb#1054)
  * libclamav: faster loading of uncompressed .cld files, also
    fixes bb#1064
  * freshclam/manager.c: add missing closesocket on error path
    (bb #1073).
* Mon Jun 16 2008 max@suse.de
- Security update 0.93.1 (bnc#399302, CVE-2008-2713)
- Improved clamav-milter configuration and init script (bnc#382907)
* Fri Apr 18 2008 max@suse.de
- Convert the database to the new format instead of running
  freshclam to re-fetch it (bnc#380787).
- Added main.cld and daily.cld as %%ghost
- Refined the logic in %%post of clamav-db as to when the dist
  files need to get copied over.
* Tue Apr 15 2008 max@suse.de
- Security update 0.93 (bnc#350987, bnc#368963).
- CVE-2007-6595: symlink attack on temporary files
- CVE-2007-6596: recognize Base64 UUEncoded archives
- CVE-2008-1100: Buffer overflow in the cli_scanpe function.
- Remove bogus dependencies from libclamav.pc (bnc#196236)
- Run freshclam on update before restarting clamd to convert the
  database into the new format.
* Wed Feb 13 2008 max@suse.de
- Security update 0.92.1: (bnc#361374)
  * CVE-2008-0318: libclamav PE File Integer Overflow Vulnerability
  * CVE-2008-0728: heap corruption
* Tue Jan 15 2008 aj@suse.de
- Fix open call to build again.
* Fri Dec 14 2007 max@suse.de
- Security update 0.92 (#343277):
  * CVE-2007-6335 - MEW PE File Integer Overflow
  * CVE-2007-6336 - Off-by-one error in LZX_READ_HUFFSYM()
  * CVE-2007-6337 - bzlib issue
- Make clamd error out if /dev/null can't be opened (#300019).
* Mon Nov  5 2007 max@suse.de
- Added sendmail and sendmail-devel to BuildRequires.
- Enabled clamav-milter and added an init script for it.
  (fate#302362)
* Tue Aug 21 2007 max@suse.de
- Bugfix update 0.91.2.
- Fixes some NULL dereferences and variable initialisation problems
- Fix some rpmlint warnings in init scripts.
* Thu Aug  9 2007 max@suse.de
- Inform the user that to use Clamuko, clamd needs to run as root,
  so that it can read the files it needs to scan (#201730).
* Tue Jul 17 2007 max@suse.de
- Stability and bugfix update: 0.91.1 (#292297)
- Run ldconfig on (un)installation.
- Make %%check conditional to fix building on SLES8.
* Sat Jul 14 2007 lrupp@suse.de
- add zlib-devel to build requires
- suppress some false positives from rpmlint
- added %%check section and remove unneeded INSTALL file from %%doc
* Wed Jul 11 2007 max@suse.de
- Update to version 0.91 (#289830)
- improved handling of .mdb files (fixes long startup times)
- Adds anti-phishing support
- unpacker for NSIS (Nullsoft Scriptable Install System)
  self-extracting archives
- unpacker for ASPack 2.12
- new implementation of the Aho-Corasick pattern matcher providing
  better detection for wildcard enabled signatures
- support for nibble matching and floating offsets
- extraction of PE files embedded into other executables
- better handling of PE & UPX
- removed dependency on libcurl (improves stability)
- many other improvements and bugfixes
* Thu May 31 2007 max@suse.de
- Security update: 0.90.3 (#279536)
- libclamav/unsp.c: fix end of buffer calculation (bb#464)
- libclamav/others.c: use strict permissions (0600) for temporary files
  created in cli_gentempstream() (bb#517).
- libclamav/unrar/unrar.c: heap corruption causing DoS with corrupted
  rar archive, better handle truncated files
- libclamav/phishcheck.c: isURL() regex execution hangs on Solaris
- libclamav/ole2_extract.c: detect block list loop (bb#466)
* Fri Apr 13 2007 max@suse.de
- Security update: 0.90.2 (#264189)
- CVE-2007-1997: CAB File Unstore Buffer Overflow Vulnerability
- CVE-2007-1745: file descriptor leak in CHM handler
- File descriptor leaks in libclamav/pdf.c and libclamav/lockdb.c
* Mon Mar  5 2007 max@suse.de
- Extended the database presence check in rcclamd to accept the
  main.inc directory in addition to the main.cvd file, because
  freshclam can delete the file during a scripted update.
* Fri Mar  2 2007 max@suse.de
- Update to version 0.90.1 (#250566)
- Some bug fixes and code improvements
- Bumps the version of libclamav's soname, which should have been
  done in 0.90 already.
* Tue Feb 20 2007 max@suse.de
- Update to version 0.90 (#246214) to fix two Vulnerabilities:
  - CAB File Denial of Service (CVE-2007-0897)
  - MIME Parsing Directory Traversal (CVE-2007-0898)
- Other changes of 0.90 include:
  - Changed config file syntax (automatic conversion is done by the
    RPM on update)
  - New unpacker for RAR3, RAR2 and RAR1
  - Rewritten unpackers for Zip and CAB files
  - Support for RAR-SFX, Zip-SFX and CAB-SFX archives
  - New PE parsing model
  - Support for PE32+ (64-bit) executables
  - Support for MD5 signatures based on PE sections (.mdb)
  - ELF file parser
  - Support for Sensory Networks' NodalCore hardware acceleration
    technology
  - Algorithmic detection can be controlled with CL_SCAN_ALGORITHMIC
  - Support for new obfuscators: SUE, Y0da Cryptor, CryptFF
  - Support for new packers: NsPack, wwpack32, MEW, Upack
  - Support for SIS files (SymbianOS packages)
  - Support for PDF and RTF files
  - TCP and local sockets can be operated simultaneously
  - New command: MULTISCAN (scan directory with multiple threads)
- There where also some API/ABI changes which might affect packages
  that link against libclamav. Affected functions are: cl_loaddb,
  cl_loaddir and cl_scanbuff.
- Cleaned up daemonizing of clamd and freshclam.
* Tue Dec 12 2006 max@suse.de
- Security update: 0.88.7 (#227827, CVE-2006-5874)
  - handle consecutive errors in base64 decoding
  - honour recursion limit when scanning email messages
  - clamscan: new option --mail-max-recursion
  - libclamav/untar.c: honour archive limits
* Tue Nov  7 2006 max@suse.de
- Add homedir of user vscan to the package (FATE300731).
* Mon Nov  6 2006 max@suse.de
- Bugfix release: 0.88.6 (#218313)
- freshclam: apply timeout patch from Everton da Silva Marques
  (new options: ConnectTimeout and ReceiveTimeout)
- clamd: change stack size at the right place (closes bug#103)
- libclamav/petite.c: sanity check the number of rebuilt sections
  (speeds up handling of malformed files)
* Tue Oct 17 2006 max@suse.de
- Bugfix release 0.88.5 fixes two serious security issues.
  [#212898], CVE-2006-4182, CVE-2006-5295
* Tue Aug  8 2006 lnussel@suse.de
- New version 0.88.4 fixes heap overflow in UPX decoder
* Thu Jul  6 2006 max@suse.de
- Bugfix release 0.88.3:
  - fix possible false matches of alternatives
  - Large binhex files were not being handled gracefully.
  - fix zero allocation warning
- Added bc and pkgconfig to BuildRequires to fix curl version
  detection.
- Prevent a file conflict on the database files when main and db
  packages of different versions are installed.
- Renamed clamav.conf to clamd.conf for SLES9.
- Added the db subpackage to SLES9.
- Bugzilla: 190647
* Tue May  2 2006 max@suse.de
- New version: 0.88.2
- Fixes a buffer overflow in freshclam's get_database function
  (CVE-2006-1989, Bug #171496).
* Mon Apr 10 2006 meissner@suse.de
- Fixed several implicit warnings which lead to failures
  on 64bit platforms.
* Wed Apr  5 2006 max@suse.de
- New version: 0.88.1, fixes several security issues:
  CVE-2006-1614, CVE-2006-1615, CVE-2006-1630, bug #164039.
* Thu Feb  9 2006 max@suse.de
- Removed unneeded dependencies from the init script to break a
  dependency loop.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Thu Jan 12 2006 max@suse.de
- Added gcc-4.1 stack protection (-fstack-protector).
* Mon Jan  9 2006 max@suse.de
- New version: 0.88 (Bug #142298).
* Mon Nov  7 2005 lnussel@suse.de
- Security update: version 0.87.1 (#132305, CVE-2005-3239,
  CVE-2005-3303)
* Mon Sep 19 2005 max@suse.de
- New version: 0.87 (bug #117648).
* Mon Jul 25 2005 max@suse.de
- New version: 0.86.2
* Thu Jul 14 2005 max@suse.de
- New version: 0.86.1
* Tue Jun 21 2005 max@suse.de
- New version: 0.86
* Tue May 17 2005 max@suse.de
- New version: 0.85.1 (Bug #81264).
* Wed May 11 2005 max@suse.de
- New version: 0.85 (Bug #81264).
* Tue May  3 2005 max@suse.de
- New version: 0.84 (Bug #81264).
- Added and special-cased the patch that is needed for 9.1/SLES9.
* Fri Mar 11 2005 max@suse.de
- Fixed %%doc file list (wildcards matched too much).
* Mon Feb 28 2005 max@suse.de
- New version: 0.83
* Mon Feb  7 2005 max@suse.de
- New version: 0.82
* Thu Jan 27 2005 max@suse.de
- New version: 0.81
* Thu Nov 11 2004 max@suse.de
- pkgconfig files go to libdir rather than /usr/lib.
* Thu Nov 11 2004 coolo@suse.de
- fixing file list for debug packages
* Wed Nov  3 2004 max@suse.de
- Fixed path to freshclam in init script, and rcfreshclam link.
* Mon Oct 18 2004 max@suse.de
- Updated to the final 0.80 release.
- Added a runlevel script for freshclam.
* Mon Oct 11 2004 max@suse.de
- Updated to 0.80rc4.
* Wed Sep 29 2004 max@suse.de
- Updated to 0.80rc3. The README says:
  "This release candidate eliminates possible false positive alerts
  in UPX/FSG compressed files and clarifies behaviour of default
  actions in clamd and freshclam."
- This also eliminates the need to patch configure.in in order to
  recognize resolv.
* Thu Sep 23 2004 max@suse.de
- Updated to 0.80rc2 which fixes a critical bug in the handling of
  empty lines in text/plain emails.
- Build with curl support.
- Fixed building of shared libraries instead of static.
- Removed unneeded %%run_ldconfig calls.
- Fixed file lists.
- Check for main.cvd instead of daily.cvd on daemon startup.
* Mon Sep 20 2004 max@suse.de
- Updated to version 0.80rc which adds support for more file
  formats, and HTML parsing. See the README file for details.
- Added a warning to the init script if no virus database is
  installed.
* Thu Aug  5 2004 max@suse.de
- New version: 0.75.1
- Moved the virus database files into a subpackage, as they are
  large and not needed if the database is kept up to date with
  freshclam.
* Fri Jul 23 2004 max@suse.de
- New version: 0.75
* Thu Jul  8 2004 max@suse.de
- Added -fno-strict-aliasing to CFLAGS.
* Mon Jul  5 2004 max@suse.de
- New version: 0.74
* Tue Jun 15 2004 max@suse.de
- New version: 0.73
* Mon Apr 26 2004 max@suse.de
- New version: 0.70
- Changes the format of the virus definition file.
* Mon Feb 16 2004 max@suse.de
- New version: 0.67
- Added support for tcpd (/etc/hosts.{allow,deny}).
- Obsoletes clamav-manager.patch.
* Fri Feb 13 2004 max@suse.de
- New version: 0.66
- Fixes a remote DoS vulnerability (Bug #34412).
* Tue Jan 27 2004 max@suse.de
- New package: ClamAV Anti-Virus Toolkit
